@@ -24,13 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApachePostReader.h 638 2005-09-07 21:51:26Z svn $
+ * $Id: ApachePostReader.h 899 2005-10-24 17:25:34Z svn $
  *****************************************************************************/
 
-#ifndef APACHEPOSTREADER_H
-#define APACHEPOSTREADER_H
-
-#include "PostReader.h"
+#ifndef APACHE_POST_READER_H
+#define APACHE_POST_READER_H
 
 #undef PACKAGE_BUGREPORT
 #undef PACKAGE_NAME
@@ -44,12 +42,12 @@
 #undef PACKAGE_TARNAME
 #undef PACKAGE_VERSION
 
-#include "apr.h"
-#include "apr_buckets.h"
-
 #undef strtoul
 
-#include <cstdlib>
+#include "PostReader.h"
+
+#include "apr.h"
+#include "apr_buckets.h"
 
 #ifdef HAVE_CONFIG_H
 #include "mod_uploader_config.h"
@@ -58,20 +56,49 @@
 using namespace std;
 
 /**
- * @brief Apache Ǥ POST ꥯȤɤ߹९饹
+ * @brief Apache  POST ꥯȤɤ߹९饹
  */
 class ApachePostReader : public PostReader
 {
 public:
-    ApachePostReader(apr_size_t block_size, request_rec *r, progress *progress);
+    /**
+     * 󥹥ȥ饯Ǥ
+     *
+     * @param[in] progress Ľ֥
+     * @param[in] request ꥯ
+     */
+    ApachePostReader(progress *progress, request_rec *request);
+    /**
+     * POST ꥯȤɤ߹ߤޤ
+     *
+     * @param[in] buffer ɤ߹ǡ񤭹Хåե
+     * @param[in] size ɤ߹ॵ
+     * @param[out] read_size ºݤɤ߹
+     */
     void read(char *buffer, apr_size_t size, apr_size_t *read_size);
-private:
-    request_rec *request_;
-    apr_bucket_brigade *brigade_;
-    apr_bucket *bucket_;
-    bool is_eos_;
+    /**
+     * ǥȥ饯Ǥ
+     *
+     * brigade_ ˴ޤ
+     */
+    ~ApachePostReader();
 
+private:
+    /**
+     *  brigade ޤ
+     *
+     * @exception const char * brigade μ˼Ԥ
+     */
     void get_brigade();
+
+    /** ꥯ */
+    request_rec *request_;
+    /** brigade */
+    apr_bucket_brigade *brigade_;
+    /** bucket */
+    apr_bucket *bucket_;
+    /** Ǹޤɤ߹ɤ */
+    bool is_eos_;
 };
 
 #endif
