@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.h 674 2005-09-13 18:31:36Z svn $
+ * $Id: Auxiliary.h 914 2005-11-17 15:07:03Z svn $
  *****************************************************************************/
 
 #ifndef AUXILIARY_H
@@ -36,6 +36,7 @@
 #endif
 
 #include "apr_pools.h"
+#include "apr_time.h"
 
 #include <stdlib.h>
 
@@ -43,27 +44,21 @@
 #include "mod_uploader_config.h"
 #endif
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+const char *escape_html(apr_pool_t *pool, const char* str);
 const char *rfc1738_encode(apr_pool_t *pool, const char* str);
+const char *rfc1738_decode(apr_pool_t *pool, const char* str);
 const char *size_str(apr_pool_t *pool, apr_uint64_t size);
 const char *comma_str(apr_pool_t *pool, apr_size_t number);
+apr_time_t parse_rfc822(apr_pool_t *pool, const char *str);
 const char *basename_ex(const char *path);
 const char *dirname_ex(apr_pool_t *pool, const char *path);
-#ifndef HAVE_STRNSTR
-char *strnstr(const char * const s, const char * const p, size_t count);
-#endif
 #ifndef HAVE_STRNCHR
-char *strnchr(const char *s, size_t count, int c);
+const char *strnchr(const char *s, size_t length, int c);
 #endif
 #if !defined(HAVE_MEMMEM) || defined(WIN32)
 void *memmem(const void *haystack, size_t haystacklen,
              const void *needle, size_t needlelen);
 #endif
-#ifdef __cplusplus
-}
-#endif
 
 #endif
 
