@@ -24,11 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BasicFileWriter.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: BasicFileWriter.h 733 2005-09-24 20:00:54Z svn $
  *****************************************************************************/
 
-#ifndef BASICFILEWRITER_H
-#define BASICFILEWRITER_H
+#ifndef BASIC_FILE_WRITER_H
+#define BASIC_FILE_WRITER_H
 
 #include "FileWriter.h"
 
@@ -48,7 +48,23 @@ using namespace std;
 class BasicFileWriter: public FileWriter
 {
 public:
+    /**
+     * 󥹥ȥ饯
+     *
+     * offset ꤵƤϡΰְʹߤ˽񤭽ФԤޤ
+     *
+     * @param[in] pool ס
+     * @param[in] fd եϥɥ
+     * @param[in] offset 񤭽Ф򳫻Ϥ
+     */
     BasicFileWriter(apr_pool_t *pool, apr_file_t *fd, apr_size_t offset=0);
+    /**
+     * եؤν񤭽ФԤޤ
+     *
+     * @param[in] buf 񤭽Фǡ
+     * @param[in] size 񤭽Ф
+     * @exception const char * 񤭽Ф˼Ԥ
+     */
     void write(const void *buf, apr_size_t size);
 private:
     BasicFileWriter(const BasicFileWriter&);
