@@ -27,15 +27,13 @@
  * $Id: ApachePostReader.h 570 2005-09-02 21:21:36Z svn $
  *****************************************************************************/
 
-#ifndef CGIPOSTREADER_H
-#define CGIPOSTREADER_H
+#ifndef CGI_POST_READER_H
+#define CGI_POST_READER_H
 
 #include "PostReader.h"
 
 #include "apr.h"
 
-#undef strtoul
-
 #include <cstdlib>
 
 #ifdef HAVE_CONFIG_H
@@ -50,9 +48,23 @@ using namespace std;
 class CGIPostReader : public PostReader
 {
 public:
-    CGIPostReader(apr_size_t block_size, progress *progress);
+    /**
+     * 󥹥ȥ饯Ǥ
+     *
+     * @param[in] progress Ľ֥
+     */
+    CGIPostReader(progress *progress);
+    /**
+     * POST ꥯȤɤ߹ߤޤ
+     *
+     * @param[in] buffer ɤ߹ǡ񤭹Хåե
+     * @param[in] size ɤ߹ॵ
+     * @param[out] read_size ºݤɤ߹
+     */
     void read(char *buffer, apr_size_t size, apr_size_t *read_size);
+
 private:
+    /** Ǹޤɤ߹ɤ */
     bool is_eof_;
 };
 
