@@ -24,11 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: FileWriter.h 469 2005-07-19 00:23:53Z svn $
+ * $Id: FileWriter.h 733 2005-09-24 20:00:54Z svn $
  *****************************************************************************/
 
-#ifndef FILEWRITER_H
-#define FILEWRITER_H
+#ifndef FILE_WRITER_H
+#define FILE_WRITER_H
 
 #include "apr_file_io.h"
 
@@ -45,9 +45,32 @@ using namespace std;
 class FileWriter
 {
 public:
+    /**
+     * 󥹥ȥ饯
+     *
+     * @param[in] pool ס
+     * @param[in] fd եϥɥ
+     */
     FileWriter(apr_pool_t *pool, apr_file_t *fd);
+    /**
+     * եؤν񤭽ФԤޤ
+     *
+     * @param[in] buf 񤭽Фǡ
+     * @param[in] size 񤭽Ф
+     * @exception const char * 񤭽Ф˼Ԥ
+     */
     virtual void write(const void *buf, apr_size_t size) = 0;
+    /**
+     * եĤޤ
+     *
+     * @exception const char * ĤΤ˼Ԥ
+     */
     virtual void close();
+    /**
+     * ǥȥ饯
+     *
+     * եĤޤ
+     */
     virtual ~FileWriter();
 protected:
     apr_pool_t *get_pool()
@@ -61,12 +84,15 @@ protected:
     }
 
 private:
-    apr_pool_t *pool_;
-    apr_file_t *fd_;
-    bool is_closed_;
-
     FileWriter(const FileWriter &);
     FileWriter &operator=(const FileWriter &);
+
+    /** ס */
+    apr_pool_t *pool_;
+    /** եϥɥ */
+    apr_file_t *fd_;
+    /** ˥ե뤬 close 줿ɤ */
+    bool is_closed_;
 };
 
 #endif
