@@ -24,11 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MessageDigest5.h 682 2005-09-15 06:41:06Z svn $
+ * $Id: MessageDigest5.h 733 2005-09-24 20:00:54Z svn $
  *****************************************************************************/
 
-#ifndef MESSAGEDIGEST5_H
-#define MESSAGEDIGEST5_H
+#ifndef MESSAGE_DIGEST5_H
+#define MESSAGE_DIGEST5_H
 
 #include "apr.h"
 
@@ -52,16 +52,9 @@ public:
     const char *c_str();
 
 private:
+    /** ǸΥѥǥѥǡ0x8000_0000_0000_0000 */
     static const apr_byte_t PADDING[64];
 
-    apr_uint32_t state_[4];
-    apr_uint32_t size_[2];
-    apr_byte_t buffer_[64];
-    apr_size_t remain_length_;
-    bool is_finish_;
-    apr_byte_t digest_bytes_[16];
-    char digest_str_[33];
-
     apr_uint32_t f(apr_uint32_t x, apr_uint32_t y, apr_uint32_t z);
     apr_uint32_t g(apr_uint32_t x, apr_uint32_t y, apr_uint32_t z);
     apr_uint32_t h(apr_uint32_t x, apr_uint32_t y, apr_uint32_t z);
@@ -79,11 +72,42 @@ private:
     apr_uint32_t round4(apr_uint32_t a, apr_uint32_t b, apr_uint32_t c,
                         apr_uint32_t d, apr_uint32_t x, apr_uint32_t s,
                         apr_uint32_t t);
-
+    /**
+     * ȥ륨ǥΥХ apr_uint32_t Ѵޤ
+     *
+     * ХĹϡ64 Ǥ
+     *
+     * @param[in] bytes Х
+     * @param[out] ints apr_uint32_t 
+     */
     void byte2int(const apr_byte_t *bytes, apr_uint32_t *ints);
+    /**
+     * apr_uint32_t ȥ륨ǥΥХѴޤ
+     *
+     * @param[in] ints apr_uint32_t 
+     * @param[in] len apr_uint32_t Ĺ
+     * @param[out] bytes Х
+     */
     void int2byte(const apr_uint32_t *ints, apr_size_t len, apr_byte_t *bytes);
     void process(const apr_byte_t block[64]);
+    /** ϥåͤ򻻽Фޤ */
     void create_digest();
+
+    MessageDigest5(const MessageDigest5&);
+    MessageDigest5 &operator=(const MessageDigest5&);
+
+    apr_uint32_t state_[4];
+    /** Ϥ bit  */
+    apr_uint32_t size_[2];
+    apr_byte_t buffer_[64];
+    /** Хåե˻ĤäƤ륵 */
+    apr_size_t remain_length_;
+    /** ˥ϥåͤ򻻽ФƤ뤫ɤ */
+    bool is_finish_;
+    /** ϥåͤΥХɽ */
+    apr_byte_t digest_bytes_[16];
+    /** ϥåͤʸ */
+    char digest_str_[33];
 };
 
 #endif
@@ -92,3 +116,11 @@ private:
 // mode: c++
 // buffer-file-coding-system: euc-japan-dos
 // End:
+
+
+
+
+
+
+
+
