@@ -1,5 +1,5 @@
 /******************************************************************************
- * mod_uploader / PostReader.cpp
+ * mod_uploader / PostReader.h
  ******************************************************************************
  * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
@@ -24,11 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostReader.h 638 2005-09-07 21:51:26Z svn $
+ * $Id: PostReader.h 863 2005-10-18 16:03:08Z svn $
  *****************************************************************************/
 
-#ifndef POSTREADER_H
-#define POSTREADER_H
+#ifndef POST_READER_H
+#define POST_READER_H
 
 #include "apr.h"
 #include "apr_time.h"
@@ -47,14 +47,41 @@ using namespace std;
 class PostReader
 {
 public:
+    /**
+     * POST ꥯȤοĽ
+     */
     typedef struct Progress {
+        /** åץ ID */
         apr_size_t upload_id;
+        /** POST ꥯȤΥȡ륵 */
         apr_size_t total_size;
+        /** ɤ߹ߺѤߤΤΥȡ륵 */
         apr_size_t read_size;
+        /** POST ꥯȤδλ */
         apr_time_t end_time;
+        /** ¾Υǡ */
+        void *data;
     } progress;
 
-    PostReader(apr_size_t block_size, progress *progress);
+    /**
+     * 󥹥ȥ饯Ǥ
+     *
+     * @param[in] progress Ľ֥
+     */
+    PostReader(progress *progress);
+    /**
+     * ꥯȤɤ߹ñ̤򥻥åȤޤ
+     *
+     * @param[in] block_size ꥯȤɤ߹ñ
+     */
+    void set_block_size(apr_size_t block_size);
+    /**
+     * POST ꥯȤɤ߹ߤޤ
+     *
+     * @param[in] buffer ɤ߹ǡ񤭹Хåե
+     * @param[in] size ɤ߹ॵ
+     * @param[out] read_size ºݤɤ߹
+     */
     virtual void read(char *buffer, apr_size_t size, apr_size_t *read_size) = 0;
     virtual ~PostReader();
 
@@ -63,7 +90,17 @@ protected:
     apr_size_t get_block_size();
 
 private:
+    /** ꥯȤɤ߹ñ̤Υǥե */
+    static const apr_size_t DEFAULT_BLOCK_SIZE;
+
+    /**
+     * ꥯȤɤ߹ñ
+     *
+     * ͤܰ¤Ǥɬǻꤷ read ɬפ
+     * ޤ
+     */
     apr_size_t block_size_;
+    /** Ľ֥ */
     progress *progress_;
 };
 
