@@ -24,11 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.h 543 2005-08-31 17:25:22Z svn $
+ * $Id: TemplateLexer.h 921 2005-11-22 10:57:19Z svn $
  *****************************************************************************/
 
-#ifndef TEMPLATELEXER_H
-#define TEMPLATELEXER_H
+#ifndef TEMPLATE_LEXER_H
+#define TEMPLATE_LEXER_H
 
 #include "apr_pools.h"
 
