@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateParser.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: TemplateParser.h 811 2005-10-01 18:49:36Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATEPARSER_H
@@ -179,11 +179,12 @@ private:
         ident_map * const imap;
 
         Handle(token_vector* tvector, ident_map *ident_map)
-            : imap(ident_map)
+            : token(tvector->begin()),
+              token_start(tvector->begin()),
+              token_end(tvector->end()),
+              imap(ident_map)
         {
-            token       = tvector->begin();
-            token_start = tvector->begin();
-            token_end   = tvector->end();
+
         }
     } handle;
 
