@@ -24,42 +24,49 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateVariableCreator.h 355 2005-05-08 05:19:50Z svn $
+ * $Id: TemplateVariableCreator.h 750 2005-09-25 13:42:21Z svn $
  *****************************************************************************/
 
-#ifndef TEMPLATEVARIABLECREATOR_H
-#define TEMPLATEVARIABLECREATOR_H
+#ifndef TEMPLATE_VARIABLE_CREATOR_H
+#define TEMPLATE_VARIABLE_CREATOR_H
+
+#include "TemplateVariable.h"
+
+#include "apr_pools.h"
 
 #ifdef HAVE_CONFIG_H
 #include "mod_uploader_config.h"
 #endif
 
-#include "TemplateExecutor.h"
-#include "UploadItem.h"
-
-#include "apr_pools.h"
-#include "apr_hash.h"
-#include "apr_tables.h"
-
 using namespace std;
 
 /**
- * ƥץ졼ȤŬѤѿ륯饹
+ * @brief ƥץ졼Ȥѿ륯饹
  */
 class TemplateVariableCreator
 {
- public:
-    typedef TemplateExecutor::variable variable;
-    typedef TemplateExecutor::scalar scalar;
+public:
+    TemplateVariableCreator(apr_pool_t *pool);
+    TemplateVariable::variable *create_variable(TemplateVariable::variable_type type);
+    TemplateVariable::scalar *create_scalar(TemplateVariable::scalar_type type);
 
-    static TemplateExecutor::variable *create(apr_pool_t *pool, UploadItem *item);
-    static TemplateExecutor::variable *create(apr_pool_t *pool, const char *str);
-    static TemplateExecutor::variable *create(apr_pool_t *pool, apr_hash_t *hash);
-    static TemplateExecutor::variable *create(apr_pool_t *pool, apr_array_header_t *array);
+    static apr_size_t get_ident_id(TemplateVariable::ident_map *imap, const char *name);
 
 private:
-    TemplateVariableCreator(const TemplateVariableCreator &);
-    TemplateVariableCreator &operator=(const TemplateVariableCreator &);
+    typedef TemplateVariable::ident_map     ident_map;
+    typedef TemplateVariable::scalar        scalar;
+    typedef TemplateVariable::scalar_type   scalar_type;
+    typedef TemplateVariable::variable      variable;
+    typedef TemplateVariable::variable_type variable_type;
+
+    static const apr_size_t VARIABLE_POOL_NUM;
+    static const apr_size_t SCALAR_POOL_NUM;
+
+    apr_pool_t *pool_;
+    variable *variable_pool_;
+    variable *variable_pool_end_;
+    scalar *scalar_pool_;
+    scalar *scalar_pool_end_;
 };
 
 #endif
