@@ -24,12 +24,15 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 684 2005-09-15 07:12:00Z svn $
+ * $Id: UploadItem.h 899 2005-10-24 17:25:34Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEM_H
 #define UPLOADITEM_H
 
+#include "Auxiliary.h"
+#include "Misc.h"
+
 #include "apr_pools.h"
 #include "apr_time.h"
 
@@ -46,8 +49,8 @@ using namespace std;
  */
 class UploadItem
 {
-    friend class TemplateVariableCreator;
     friend class UploadItemCreator;
+    friend class UploadVariableCreator;
 
 public:
     static const apr_size_t MAX_IDENTIFIER_LENGTH       = 16;
@@ -94,15 +97,61 @@ public:
     explicit UploadItem(apr_pool_t *pool);
     header *set_data(const char *file_path, header *header);
     header *get_header() const;
-    const char *get_file_path() const;
-    const char *get_file_name() const;
-    const char *get_file_digest() const;
-    const char *get_comment() const;
-    const char *get_remove_pass() const;
-    const char *get_download_pass() const;
-    const char *get_file_size() const;
-    const char *get_file_mime() const;
-    const char *get_time() const;
+
+    const char *get_file_path() const
+    {
+        return file_path_;
+    };
+
+    const char *get_file_name() const
+    {
+        return header_->file_name;
+    };
+
+    const char *get_file_digest() const
+    {
+        return header_->file_digest;
+    };
+
+    const char *get_comment() const
+    {
+        return header_->comment;
+    };
+
+    const char *get_remove_pass() const
+    {
+        return header_->remove_pass;
+    };
+
+    const char *get_download_pass() const
+    {
+        return header_->download_pass;
+    };
+
+    const char *get_file_size() const
+    {
+        return size_str(pool_, header_->file_size);
+    };
+
+    const char *get_file_mime() const
+    {
+        return header_->file_mime;
+    };
+
+    const char *get_time() const
+    {
+        apr_time_exp_t time_exp;
+        char *time_str;
+        apr_size_t size;
+
+        APR_PALLOC(time_str, char *, pool_, sizeof(char)*MAX_TIME_LENGTH);
+
+        apr_time_exp_tz(&time_exp, header_->time, TIME_ZONE_OFFSET);
+        apr_strftime(time_str, &size, MAX_TIME_LENGTH, TIME_FORMAT, &time_exp);
+
+        return time_str;
+    };
+
 #ifdef DEBUG
     static void dump_header(header *header);
 #endif
