@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemCreator.h 642 2005-09-07 23:26:55Z svn $
+ * $Id: UploadItemCreator.h 837 2005-10-10 11:18:34Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEMCREATOR_H
@@ -35,19 +35,7 @@
 #endif
 
 #include "UploadItem.h"
-#include "RFC1867ParserImpl.h"
-
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#include "httpd.h"
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
+#include "RFC1867Data.h"
 
 #include "apr_pools.h"
 
@@ -61,18 +49,28 @@ using namespace std;
 class UploadItemCreator
 {
 public:
-    static UploadItem::header *create_header(apr_pool_t *pool, UploadParser::query_map *qmap,
+    static UploadItem::header *create_header(apr_pool_t *pool,
+                                             RFC1867Data::query_map *qmap,
                                              const char **file_path);
 private:
-    UploadItemCreator(const UploadItemCreator&);
-    UploadItemCreator &operator=(const UploadItemCreator&);
+    typedef RFC1867Data::rfc1867_content content;
+
+    static void validate_query(apr_pool_t *pool, RFC1867Data::query_map *qmap);
+    static void validate_file(apr_pool_t *pool, content& content,
+                              const unsigned char *code_pat);
+    static void validate_comment(apr_pool_t *pool, content& content,
+                                 const unsigned char *code_pat);
+    static void validate_download_pass(apr_pool_t *pool, content& content);
+    static void validate_remove_pass(apr_pool_t *pool, content& content);
 
-    static void validate_query(apr_pool_t *pool, UploadParser::query_map *qmap);
     static void convert_code(apr_pool_t *pool, string &str, const unsigned char *code_pat);
     static void escape_html(apr_pool_t *pool, string &str);
     static void set_file_data(apr_pool_t *pool, UploadItem::header *data,
-                              UploadParser::file_content& file,
-                              UploadParser::query_map *qmap);
+                              RFC1867Data::file_content& file,
+                              RFC1867Data::query_map *qmap);
+
+    UploadItemCreator(const UploadItemCreator&);
+    UploadItemCreator &operator=(const UploadItemCreator&);
 };
 
 #endif
