@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 684 2005-09-15 07:12:00Z svn $
+ * $Id: UploadItemList.h 746 2005-09-25 09:27:50Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEMLIST_H
@@ -32,7 +32,7 @@
 
 #include "UploadItem.h"
 #include "UploadItemReader.h"
-#include "TemplateExecutor.h"
+#include "TemplateVariable.h"
 #ifdef MAKE_THUMBNAIL
 #include "ThumbnailWriter.h"
 #endif
@@ -69,14 +69,17 @@ public:
     bool empty() const;
     apr_uint64_t get_total_file_size() const;
     apr_size_t get_thumb_size() const;
+
     apr_time_t get_mtime() const;
-    void update_mtime();
-    bool is_need_update(apr_pool_t *pool) const;
+    apr_size_t get_revision() const;
+    void set_revision(apr_size_t revision);
+
     void remove(const char *file_path, const char *password);
-    TemplateExecutor::variable *to_varray(apr_pool_t *pool,
+
+    TemplateVariable::variable *to_varray(apr_pool_t *pool,
                                           apr_size_t start,
                                           apr_size_t size) const;
-    TemplateExecutor::variable *to_thumb_varray(apr_pool_t *pool,
+    TemplateVariable::variable *to_thumb_varray(apr_pool_t *pool,
                                                 apr_size_t start,
                                                 apr_size_t size) const;
     item_info **to_array(apr_pool_t *pool, apr_size_t start, apr_size_t size) const;
@@ -130,6 +133,8 @@ private:
     void remove(item_info *info);
     void sort();
 
+    void update_mtime();
+
     const char *create_tmp_path(apr_pool_t *tmp_pool, const char *name,
                                 bool is_buffered, apr_file_t **tmp_file);
 
@@ -163,6 +168,7 @@ private:
     item_list ilist_;
     thumb_list tlist_;
     apr_time_t mtime_;
+    apr_size_t revision_;
 };
 
 #endif
