@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemReader.h 469 2005-07-19 00:23:53Z svn $
+ * $Id: UploadItemReader.h 916 2005-11-20 15:30:59Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEMREADER_H
@@ -48,11 +48,14 @@ using namespace std;
  */
 class UploadItemReader
 {
- public:
+public:
     UploadItemReader(apr_pool_t *pool, const char *file_dir);
-    UploadItem::header *read(const char *file_name, apr_file_t **file);
-    UploadItem::header *read(const char *file_name, apr_file_t **file, apr_pool_t *pool);
- private:
+    UploadItem::header *read(const char *file_name, apr_file_t **file,
+                             bool is_buffered=true);
+    UploadItem::header *read(apr_pool_t *pool, const char *file_name,
+                             apr_file_t **file, bool is_buffered=true);
+
+private:
     UploadItemReader(const UploadItemReader&);
     UploadItemReader &operator=(const UploadItemReader&);
 
