@@ -24,40 +24,22 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.h 674 2005-09-13 18:31:36Z svn $
+ * $Id: UploaderConfig.h 898 2005-10-24 06:11:05Z svn $
  *****************************************************************************/
 
-#ifndef UPLOADERCONFIG_H
-#define UPLOADERCONFIG_H
+#ifndef UPLOADER_CONFIG_H
+#define UPLOADER_CONFIG_H
 
-#define APR_NOT_DONE_YET 0
+#include "mod_uploader_data.h"
 
-#include "httpd.h"
-#include "apr_pools.h"
-#include "apr_time.h"
-#include "apr_global_mutex.h"
-#ifdef LOCK_TYPE_MUTEX
-#include "apr_thread_mutex.h"
-#else
-#include "apr_thread_rwlock.h"
-#endif
-
-#undef strtoul
-
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-
-#include "RFC1867ParserImpl.h"
 #include "UploadItemWriter.h"
 #include "UploadItemReader.h"
 #include "UploadItemList.h"
 #include "TemplateLexer.h"
 #include "TemplateParser.h"
-#include "TemplateExecutor.h"
 
+#include "apr_pools.h"
+#include "apr_time.h"
 
 #include <cstdlib>
 
@@ -72,24 +54,10 @@ using namespace std;
  */
 class UploaderConfig {
 public:
-    typedef struct PageTemplate {
-        TemplateLexer::ident_map *imap;
-        TemplateParser::node *node;
-        apr_time_t mtime;
-
-        PageTemplate()
-        {
-            imap    = NULL;
-            node    = NULL;
-            mtime   = 0;
-        }
-    } page_template;
-
     UploaderConfig();
-    ~UploaderConfig();
+    virtual ~UploaderConfig();
 
-    void init(request_rec *r);
-    void finalize();
+    virtual void finalize();
 
     page_template *get_view_template(apr_pool_t *pool);
     page_template *get_progress_template(apr_pool_t *pool);
@@ -99,17 +67,12 @@ public:
 
     UploadItemReader *get_ureader(apr_pool_t *pool);
     UploadItemWriter *get_uwriter(apr_pool_t *pool);
-    void read_lock();
-    void read_unlock();
-    void gwrite_lock();
-    void gwrite_unlock();
 
     // ݤΤ public
     const char *url;
     const char *file_dir;
     const char *thumb_dir;
     const char *tmp_dir;
-    const char *magick_dir;
     const char *view_tmpl_path;
     const char *progress_tmpl_path;
     const char *download_tmpl_path;
@@ -122,10 +85,8 @@ public:
     apr_size_t remove_item_number;
 
     UploadItemList *item_list;
-    TemplateExecutor *texecutor;
-    UploadParser *uparser;
 
-private:
+protected:
     static const apr_uint64_t TOTAL_FILE_SIZE_LIMIT;
     static const apr_size_t TOTAL_FILE_NUMBER_LIMIT;
     static const apr_size_t MAX_FORM_FILE_SIZE;
@@ -134,24 +95,6 @@ private:
     static const apr_size_t PER_PAGE_ITEM_NUMBER;
     static const apr_size_t ITEM_RELOAD_THRESHOLD;
 
-    void exec_init();
-    void validate();
-#if APR_HAS_THREADS
-    void init_lock();
-#endif
-    void load_list();
-    void update_list(apr_pool_t *pool);
-    void load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
-                       const char *template_path, page_template *tmpl);
-
-    void write_lock();
-    void write_unlock();
-    void global_lock();
-    void global_unlock();
-
-    static apr_time_t get_mtime(apr_pool_t *pool, const char *path);
-
-    apr_pool_t *pool_;
     page_template *view_tmpl_;
     apr_pool_t *view_tmpl_pool_;
     page_template *progress_tmpl_;
@@ -162,16 +105,19 @@ private:
     apr_pool_t *thumb_tmpl_pool_;
     page_template *error_tmpl_;
     apr_pool_t *error_tmpl_pool_;
+    apr_pool_t *pool_;
     apr_pool_t *list_pool_;
-    apr_global_mutex_t *glock_;
-#if APR_HAS_THREADS
-#ifdef LOCK_TYPE_MUTEX
-    apr_thread_mutex_t *lock_;
-#else
-    apr_thread_rwlock_t *lock_;
-#endif
-#endif
     volatile bool is_init_;
+
+    void validate();
+    void init_template();
+    void load_list(apr_size_t revision);
+    void load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
+                       const char *template_path, page_template *tmpl);
+    void set_template_imap(apr_pool_t *tmpl_pool, page_template *tmpl,
+                           TemplateLexer::ident_map *imap);
+
+    static apr_time_t get_mtime(apr_pool_t *pool, const char *path);
 };
 
 #endif
