@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApachePostReader.cpp 638 2005-09-07 21:51:26Z svn $
+ * $Id: ApachePostReader.cpp 851 2005-10-15 15:41:52Z svn $
  *****************************************************************************/
 
 #include "ApachePostReader.h"
@@ -42,11 +42,11 @@
 /******************************************************************************
  * public ᥽å
  *****************************************************************************/
-ApachePostReader::ApachePostReader(apr_size_t block_size, request_rec *r,
-                                   progress *progress)
-    : PostReader(block_size, progress),
-      request_(r),
-      brigade_(apr_brigade_create(r->pool, r->connection->bucket_alloc)),
+ApachePostReader::ApachePostReader(progress *progress, request_rec *request)
+    : PostReader(progress),
+      request_(request),
+      brigade_(apr_brigade_create(request->pool,
+                                  request->connection->bucket_alloc)),
       bucket_(NULL),
       is_eos_(false)
 {
@@ -80,7 +80,7 @@ void ApachePostReader::read(char *buffer, apr_size_t size, apr_size_t *read_size
     }
 
     apr_bucket_read(bucket_, &read_data, read_size, APR_BLOCK_READ);
-    memmove(buffer, read_data, *read_size);
+    memcpy(buffer, read_data, *read_size);
 
     update(*read_size);
 
@@ -89,6 +89,11 @@ void ApachePostReader::read(char *buffer, apr_size_t size, apr_size_t *read_size
     return;
 }
 
+ApachePostReader::~ApachePostReader()
+{
+    apr_brigade_destroy(brigade_);
+}
+
 
 /******************************************************************************
  * private ᥽å
