@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BasicFileWriter.cpp 537 2005-08-30 21:18:51Z svn $
+ * $Id: BasicFileWriter.cpp 676 2005-09-14 14:43:48Z svn $
  *****************************************************************************/
 
 #include "BasicFileWriter.h"
@@ -50,9 +50,9 @@ BasicFileWriter::BasicFileWriter(apr_pool_t *pool, apr_file_t *fd,
 
 void BasicFileWriter::write(const void *buf, apr_size_t size)
 {
-    apr_size_t write_size = size;
+    apr_size_t write_size;
 
-    if (UNLIKELY(apr_file_write_full(get_fd(), buf, write_size, &write_size) != APR_SUCCESS)) {
+    if (UNLIKELY(apr_file_write_full(get_fd(), buf, size, &write_size) != APR_SUCCESS)) {
         throw "ե write ˼Ԥޤ";
     }
 }
