@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MessageDigest5.cpp 691 2005-09-17 04:48:38Z svn $
+ * $Id: MessageDigest5.cpp 895 2005-10-23 18:50:50Z svn $
  *****************************************************************************/
 
 #include "MessageDigest5.h"
@@ -88,16 +88,16 @@ void MessageDigest5::update(const apr_byte_t *input, apr_size_t size)
     if (LIKELY(length >= gap)) {
         read_size = 0;
 
-        memmove(buffer_+remain_length_, input, gap);
+        memcpy(buffer_+remain_length_, input, gap);
         process(buffer_);
 
         for (read_size = gap; read_size + 64 <= length; read_size += 64) {
             process(input+read_size);
         }
 
-        memmove(buffer_, input+read_size, length-read_size);
+        memcpy(buffer_, input+read_size, length-read_size);
     } else {
-        memmove(buffer_+remain_length_, input, length);
+        memcpy(buffer_+remain_length_, input, length);
     }
 
     remain_length_ = (size_[0] >> 3) & 0x3f;
@@ -205,7 +205,7 @@ void MessageDigest5::byte2int(const apr_byte_t *bytes, apr_uint32_t *ints)
 {
     apr_size_t i;
 
-    for (i = 0; i < 16; i++) {
+    for (i = 0; i < 16; ++i) {
         ints[i] = ((apr_uint32_t)bytes[i*4    ]) |
                   ((apr_uint32_t)bytes[i*4 + 1] <<  8) |
                   ((apr_uint32_t)bytes[i*4 + 2] << 16) |
@@ -217,7 +217,7 @@ void MessageDigest5::int2byte(const apr_uint32_t *ints, apr_size_t len, apr_byte
 {
     apr_size_t i;
 
-    for (i = 0; i < len; i++) {
+    for (i = 0; i < len; ++i) {
         bytes[i*4    ] = (ints[i]      ) & 0xff;
         bytes[i*4 + 1] = (ints[i] >>  8) & 0xff;
         bytes[i*4 + 2] = (ints[i] >> 16) & 0xff;
