@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.cpp 548 2005-08-31 20:29:04Z svn $
+ * $Id: MmapFileWriter.cpp 724 2005-09-24 05:02:17Z svn $
  *****************************************************************************/
 
 #include "MmapFileWriter.h"
@@ -118,7 +118,11 @@ void MmapFileWriter::close()
 
 MmapFileWriter::~MmapFileWriter()
 {
-    close();
+    try {
+        close();
+    } catch(const char *) {
+        // ̵
+    }
 }
 
 
