@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostReader.cpp 638 2005-09-07 21:51:26Z svn $
+ * $Id: PostReader.cpp 743 2005-09-25 06:11:40Z svn $
  *****************************************************************************/
 
 #include "PostReader.h"
@@ -33,17 +33,24 @@
 #include <iostream>
 #endif
 
+const apr_size_t PostReader::DEFAULT_BLOCK_SIZE = 2048;
+
 
 /******************************************************************************
  * public ᥽å
  *****************************************************************************/
-PostReader::PostReader(apr_size_t block_size, progress *progress)
-    : block_size_(block_size),
+PostReader::PostReader(progress *progress)
+    : block_size_(DEFAULT_BLOCK_SIZE),
       progress_(progress)
 {
 
 }
 
+void PostReader::set_block_size(apr_size_t block_size)
+{
+    block_size_ = block_size;
+}
+
 PostReader::~PostReader()
 {
 
@@ -55,6 +62,12 @@ PostReader::~PostReader()
  *****************************************************************************/
 void PostReader::update(apr_size_t read_size)
 {
+#ifdef DEBUG
+    if (progress_ == NULL) {
+        throw "ĽνǤƤޤ";
+    }
+#endif
+
     progress_->read_size += read_size;
 }
 
