@@ -1,5 +1,5 @@
 /******************************************************************************
- * mod_uploader / TemplateExecutorr.cpp
+ * mod_uploader / TemplateExecutor.cpp
  ******************************************************************************
  * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
@@ -24,13 +24,12 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 535 2005-08-30 20:15:17Z svn $
+ * $Id: TemplateExecutor.cpp 914 2005-11-17 15:07:03Z svn $
  *****************************************************************************/
 
 #include "TemplateExecutor.h"
 #include "Misc.h"
 
-#include "http_protocol.h"
 #include "apr_strings.h"
 
 #ifdef DEBUG
@@ -49,65 +48,68 @@
 #define TRACE(label)
 #endif
 
-const apr_size_t TemplateExecutor::VARIABLE_POOL_NUM    = TEXECUTOR_VARIABLE_POOL_NUM;
-const apr_size_t TemplateExecutor::SCALAR_POOL_NUM      = TEXECUTOR_SCALAR_POOL_NUM;
-
 
 /******************************************************************************
  * public ᥽å
  *****************************************************************************/
-TemplateExecutor::TemplateExecutor()
-{
+template<class ResponseWriterClass>
+TemplateExecutor<ResponseWriterClass>::TemplateExecutor(apr_pool_t *pool,
+                                                        TemplateParser::ident_map *imap,
+                                                        TemplateVariable::variable_map *vmap,
+                                                        ResponseWriterClass& writer)
+    : pool_(pool),
+      imap_(imap),
+      vcreator_(pool),
+      writer_(writer)
 
+{
+    // vector ٤Τǡˤ롥
+
+    variable_map::const_iterator i;
+    variable_map::const_iterator end = vmap->end();
+    apr_size_t j;
+
+    APR_PCALLOC(vmap_, variable **, pool, sizeof(variable *)*vmap->size());
+
+    j = 0;
+    for (i = vmap->begin(); i != end; ++i) {
+        vmap_[j++] = *i;
+    }
 }
 
-void TemplateExecutor::exec(apr_pool_t *pool, request_rec *request,
-                            node *node, ident_map *imap, variable_map *vmap)
+template<class ResponseWriterClass>
+void TemplateExecutor<ResponseWriterClass>::exec(TemplateParser::node *node)
 {
     TRACE("exec");
 
-    handle h(pool, request, imap, vmap);
-
-    exec_stmt(&h, node);
-}
-
-apr_size_t TemplateExecutor::get_ident_id(ident_map *imap, const char *name)
-{
-    apr_size_t id;
-
-    for (id = 0; id < imap->size(); id++) {
-        if (strcmp(imap->at(id), name) == 0) {
-            return id;
-        }
-    }
-
-    return id;
+    exec_stmt(node);
 }
 
 
 /******************************************************************************
  * private ᥽å
  *****************************************************************************/
-void TemplateExecutor::exec_stmt(handle *h, node *node)
+template<class ResponseWriterClass>
+void TemplateExecutor<ResponseWriterClass>::exec_stmt(node *node)
 {
     TRACE("exec_stmt");
 
     while (node != NULL) {
         switch (node->branch.left->type) {
-        case TemplateParser::FOREACH:       // FOREACH
-            exec_foreach(h, node->branch.left);
-            break;
-        case TemplateParser::WHILE:         // WHILE
-            exec_while(h, node->branch.left);
+        case TemplateParser::PRINT:         // PRINT
+            exec_print(node->branch.left);
             break;
         case TemplateParser::IF:            // IF
-            exec_if(h, node->branch.left);
+            exec_if(node->branch.left);
             break;
-        case TemplateParser::PRINT:         // PRINT
-            exec_print(h, node->branch.left);
+        case TemplateParser::FOREACH:       // FOREACH
+            exec_foreach(node->branch.left);
+            break;
+        case TemplateParser::WHILE:         // WHILE
+            exec_while(node->branch.left);
             break;
         default:
-            calc_i_val(h, node->branch.left);
+            calc_i_val(node->branch.left);
             break;
         }
 
@@ -115,48 +117,52 @@ void TemplateExecutor::exec_stmt(handle *h, node *node)
     }
 }
 
-void TemplateExecutor::exec_foreach(handle *h, node *node)
+template<class ResponseWriterClass>
+void TemplateExecutor<ResponseWriterClass>::exec_foreach(node *node)
 {
     TRACE("exec_foreach");
 
-    variable *array_var = h->vmap->at(node->branch.center->i_val);
+    variable *array_var = vmap_[node->branch.center->i_val];
     apr_size_t index_id = node->branch.left->i_val;
 
     if (UNLIKELY(array_var == NULL)) {
         throw "Ƥʤѿ򻲾Ȥޤ";
-    } else if (UNLIKELY(array_var->type != ARRAY)) {
+    } else if (UNLIKELY(array_var->type != TemplateVariable::ARRAY)) {
         throw "ɬפʾˤ¾ѿꤵƤޤ";
     }
 
     apr_size_t array_size = array_var->a_val->nelts;
-    for (apr_size_t i = 0; i < array_size; i++) {
-        h->vmap->at(index_id) = *(reinterpret_cast<variable **>(array_var->a_val->elts) + i);
+    for (apr_size_t i = 0; i < array_size; ++i) {
+        vmap_[index_id]= *(reinterpret_cast<variable **>(array_var->a_val->elts) + i);
 
-        exec_stmt(h, node->branch.right);
+        exec_stmt(node->branch.right);
     }
 }
 
-void TemplateExecutor::exec_while(handle *h, node *node)
+template<class ResponseWriterClass>
+void TemplateExecutor<ResponseWriterClass>::exec_while(node *node)
 {
     TRACE("exec_while");
 
-    while (calc_b_val(h, node->branch.left)) {
-        exec_stmt(h, node->branch.right);
+    while (calc_b_val(node->branch.left)) {
+        exec_stmt(node->branch.right);
     }
 }
 
-void TemplateExecutor::exec_if(handle *h, node *node)
+template<class ResponseWriterClass>
+void TemplateExecutor<ResponseWriterClass>::exec_if(node *node)
 {
     TRACE("exec_if");
 
-    if (calc_b_val(h, node->branch.center)) {
-        exec_stmt(h, node->branch.left);
+    if (calc_b_val(node->branch.center)) {
+        exec_stmt(node->branch.left);
     } else if (node->branch.right != NULL) {
-        exec_stmt(h, node->branch.right);
+        exec_stmt(node->branch.right);
     }
 }
 
-void TemplateExecutor::exec_print(handle *h, node *node)
+template<class ResponseWriterClass>
+void TemplateExecutor<ResponseWriterClass>::exec_print(node *node)
 {
     TRACE("exec_print");
 
@@ -165,31 +171,32 @@ void TemplateExecutor::exec_print(handle *h, node *node)
 
     while (node != NULL) {
         switch (node->branch.left->type) {
+        case TemplateParser::STRING:        // ʸ
+            print(node->branch.left->s_val);
+            break;
         case TemplateParser::IDENTIFIER:    // ̻
-            var = h->vmap->at(node->branch.left->i_val);
-            goto VAR;
-        case TemplateParser::ARRAY_REF:     // []
-            var = get_var(h, node->branch.left);
+            var = vmap_[node->branch.left->i_val];
             goto VAR;
         case TemplateParser::HASH_REF:      // .
-            var = get_var(h, node->branch.left);
+            var = get_var(node->branch.left);
+            goto VAR;
+        case TemplateParser::ARRAY_REF:     // []
+            var = get_var(node->branch.left);
             goto VAR;
         VAR:
             if (UNLIKELY(var == NULL)) {
                 throw "Ƥʤѿ򻲾Ȥޤ";
             }
 
-            if ((var->type == SCALAR) && (var->s_val->type == STRING)) {
-                print(h, var->s_val->s_val);
+            if ((var->type == TemplateVariable::SCALAR) &&
+                (var->s_val->type == TemplateVariable::STRING)) {
+                print(var->s_val->s_val);
             } else {
-                print(h, calc_i_val(var));
+                print(calc_i_val(var));
             }
             break;
-        case TemplateParser::STRING:        // ʸ
-            print(h, node->branch.left->s_val);
-            break;
         default:
-            print(h, calc_i_val(h, node->branch.left));
+            print(calc_i_val(node->branch.left));
             break;
         }
 
@@ -197,25 +204,27 @@ void TemplateExecutor::exec_print(handle *h, node *node)
     }
 }
 
-bool TemplateExecutor::calc_b_val(handle *h, node *node)
+template<class ResponseWriterClass>
+bool TemplateExecutor<ResponseWriterClass>::calc_b_val(node *node)
 {
     TRACE("calc_b_val");
 
     switch (node->type) {
     case TemplateParser::EQUAL:
-        return calc_i_val(h, node->branch.left) == calc_i_val(h, node->branch.right);
+        return calc_i_val(node->branch.left) == calc_i_val(node->branch.right);
     case TemplateParser::NOTEQUAL:
-        return calc_i_val(h, node->branch.left) != calc_i_val(h, node->branch.right);
+        return calc_i_val(node->branch.left) != calc_i_val(node->branch.right);
     case TemplateParser::GREATER_THAN:
-        return calc_i_val(h, node->branch.left) > calc_i_val(h, node->branch.right);
+        return calc_i_val(node->branch.left) > calc_i_val(node->branch.right);
     case TemplateParser::LESS_THAN:
-        return calc_i_val(h, node->branch.left) < calc_i_val(h, node->branch.right);
+        return calc_i_val(node->branch.left) < calc_i_val(node->branch.right);
     default:
         UNEXPECTED(false);
     }
 }
 
-int TemplateExecutor::calc_i_val(handle *h, node *node)
+template<class ResponseWriterClass>
+int TemplateExecutor<ResponseWriterClass>::calc_i_val(node *node)
 {
     TRACE("calc_i_val");
 
@@ -230,7 +239,7 @@ int TemplateExecutor::calc_i_val(handle *h, node *node)
     case TemplateParser::STRING:            // STRING
         return static_cast<int>(strlen(node->s_val));
     case TemplateParser::IDENTIFIER:        // IDENTIFIER
-        var = h->vmap->at(node->i_val);
+        var = vmap_[node->i_val];
 
         if (UNLIKELY(var == NULL)) {
             throw "Ƥʤѿ򻲾Ȥޤ";
@@ -246,46 +255,47 @@ int TemplateExecutor::calc_i_val(handle *h, node *node)
         case TemplateParser::IDENTIFIER:    // ̻
         case TemplateParser::ARRAY_REF:     // []
         case TemplateParser::HASH_REF:      // .
-            ref_var = get_var(h, node->branch.right);
+            ref_var = get_var(node->branch.right);
             if (UNLIKELY(ref_var == NULL)) {
                 throw "Ƥʤѿ򻲾Ȥޤ";
             }
 
-            if ((ref_var->type == SCALAR) && (ref_var->s_val->type == INTEGER)) {
-                var = h->vmap->at(ident_id);
+            if ((ref_var->type == TemplateVariable::SCALAR) &&
+                (ref_var->s_val->type == TemplateVariable::INTEGER)) {
+                var = vmap_[ident_id];
                 if (var == NULL) {
-                    var = create_variable(h, SCALAR);
-                    var->s_val = create_scalar(h, INTEGER);
+                    var = vcreator_.create_variable(TemplateVariable::SCALAR);
+                    var->s_val = vcreator_.create_scalar(TemplateVariable::INTEGER);
 
-                    h->vmap->at(ident_id) = var;
+                    vmap_[ident_id] = var;
                 } else {
-                    var->type = SCALAR;
-                    var->s_val->type = INTEGER;
+                    var->type = TemplateVariable::SCALAR;
+                    var->s_val->type = TemplateVariable::INTEGER;
                 }
 
                 var->s_val->i_val = ref_var->s_val->i_val;
             } else { // Ͱʳϥԡʤ
-                h->vmap->at(ident_id) = ref_var;
+                vmap_[ident_id] = ref_var;
             }
 
             return calc_i_val(var);
         case TemplateParser::STRING:        // ʸ
-            var = h->vmap->at(ident_id);
+            var = vmap_[ident_id];
             if (var == NULL) {
-                var = create_variable(h, SCALAR);
-                var->s_val = create_scalar(h, STRING);
+                var = vcreator_.create_variable(TemplateVariable::SCALAR);
+                var->s_val = vcreator_.create_scalar(TemplateVariable::STRING);
 
                 // ԡϤʤ
                 var->s_val->s_val = node->branch.right->s_val;
 
-                h->vmap->at(ident_id) = var;
+                vmap_[ident_id] = var;
             } else {
-                var->type = SCALAR;
+                var->type = TemplateVariable::SCALAR;
 
                 if (var->s_val == NULL) {
-                    var->s_val = create_scalar(h, STRING);
+                    var->s_val = vcreator_.create_scalar(TemplateVariable::STRING);
                 } else {
-                    var->s_val->type = STRING;
+                    var->s_val->type = TemplateVariable::STRING;
                 }
 
                 // ԡϤʤ
@@ -294,46 +304,46 @@ int TemplateExecutor::calc_i_val(handle *h, node *node)
 
             return calc_i_val(var);
         default:                            // 
-            var = h->vmap->at(ident_id);
+            var = vmap_[ident_id];
             if (var == NULL) {
-                var = create_variable(h, SCALAR);
-                var->s_val = create_scalar(h, INTEGER);
-                var->s_val->i_val = calc_i_val(h, node->branch.right);
+                var = vcreator_.create_variable(TemplateVariable::SCALAR);
+                var->s_val = vcreator_.create_scalar(TemplateVariable::INTEGER);
+                var->s_val->i_val = calc_i_val(node->branch.right);
 
-                h->vmap->at(ident_id) = var;
+                vmap_[ident_id] = var;
             } else {
-                var->type = SCALAR;
+                var->type = TemplateVariable::SCALAR;
 
                 if (var->s_val == NULL) {
-                    var->s_val = create_scalar(h, INTEGER);
+                    var->s_val = vcreator_.create_scalar(TemplateVariable::INTEGER);
                 } else {
-                    var->s_val->type = INTEGER;
+                    var->s_val->type = TemplateVariable::INTEGER;
                 }
-                var->s_val->i_val = calc_i_val(h, node->branch.right);
+                var->s_val->i_val = calc_i_val(node->branch.right);
             }
             return calc_i_val(var);
         }
     case TemplateParser::PLUS_ASSIGNMENT:   // +=
-        diff = calc_i_val(h, node->branch.right);
+        diff = calc_i_val(node->branch.right);
         goto ASSIGN2;
     case TemplateParser::MINUS_ASSIGNMENT:  // -=
-        diff = -calc_i_val(h, node->branch.right);
+        diff = -calc_i_val(node->branch.right);
         goto ASSIGN2;
     ASSIGN2:
         ident_id = node->branch.left->i_val;
-        var = h->vmap->at(ident_id);
+        var = vmap_[ident_id];
 
         if (var == NULL) {
-            var = create_variable(h, SCALAR);
-            var->s_val = create_scalar(h, INTEGER);
+            var = vcreator_.create_variable(TemplateVariable::SCALAR);
+            var->s_val = vcreator_.create_scalar(TemplateVariable::INTEGER);
             var->s_val->i_val = diff;
 
-            h->vmap->at(ident_id) = var;
+            vmap_[ident_id] = var;
 
             return var->s_val->i_val;
         } else {
-            var->type = SCALAR;
-            var->s_val->type = INTEGER;
+            var->type = TemplateVariable::SCALAR;
+            var->s_val->type = TemplateVariable::INTEGER;
             var->s_val->i_val = calc_i_val(var) + diff;
 
             return var->s_val->i_val;
@@ -347,35 +357,35 @@ int TemplateExecutor::calc_i_val(handle *h, node *node)
     MONADIC:
         if (node->branch.left != NULL) {
             ident_id = node->branch.left->i_val;
-            var = h->vmap->at(ident_id);
+            var = vmap_[ident_id];
 
             if (UNLIKELY(var == NULL)) {
                 throw "Ƥʤѿ򻲾Ȥޤ";
-            } else if (UNLIKELY(var->type != SCALAR)) {
+            } else if (UNLIKELY(var->type != TemplateVariable::SCALAR)) {
                 throw "SCALAR ɬפʾǤʳѿĤޤ";
             }
 
-            var->type = SCALAR;
+            var->type = TemplateVariable::SCALAR;
 
             s_val = var->s_val;
-            s_val->type = INTEGER;
+            s_val->type = TemplateVariable::INTEGER;
             s_val->i_val = calc_i_val(var);
             value = s_val->i_val;
             s_val->i_val += diff;
         } else if (node->branch.right != NULL) {
             ident_id = node->branch.right->i_val;
-            var = h->vmap->at(ident_id);
+            var = vmap_[ident_id];
 
             if (UNLIKELY(var == NULL)) {
                 throw "Ƥʤѿ򻲾Ȥޤ";
-            } else if (UNLIKELY(var->type != SCALAR)) {
+            } else if (UNLIKELY(var->type != TemplateVariable::SCALAR)) {
                 throw "SCALAR ɬפʾǤʳѿĤޤ";
             }
 
-            var->type = SCALAR;
+            var->type = TemplateVariable::SCALAR;
 
             s_val = var->s_val;
-            s_val->type = INTEGER;
+            s_val->type = TemplateVariable::INTEGER;
             s_val->i_val = calc_i_val(var);
             s_val->i_val += diff;
             value = s_val->i_val;
@@ -384,35 +394,38 @@ int TemplateExecutor::calc_i_val(handle *h, node *node)
         }
         return value;
     case TemplateParser::PLUS:              // +
-        return calc_i_val(h, node->branch.left) + calc_i_val(h, node->branch.right);
+        return calc_i_val(node->branch.left) + calc_i_val(node->branch.right);
     case TemplateParser::MINUS:             // -
-        return calc_i_val(h, node->branch.left) - calc_i_val(h, node->branch.right);
+        return calc_i_val(node->branch.left) - calc_i_val(node->branch.right);
     case TemplateParser::RESIDUE:           // %
-        return calc_i_val(h, node->branch.left) % calc_i_val(h, node->branch.right);
+        return calc_i_val(node->branch.left) % calc_i_val(node->branch.right);
     default:
         UNEXPECTED(0);
     }
 }
 
-int TemplateExecutor::calc_i_val(TemplateExecutor::variable* var)
+template<class ResponseWriterClass>
+int TemplateExecutor<ResponseWriterClass>::calc_i_val(variable* var)
 {
     switch (var->type) {
-    case SCALAR:
-        if (var->s_val->type == INTEGER) {
+    case TemplateVariable::SCALAR:
+        if (var->s_val->type == TemplateVariable::INTEGER) {
             return var->s_val->i_val;
         } else {
             return static_cast<int>(strlen(var->s_val->s_val));
         }
-    case ARRAY:
+    case TemplateVariable::ARRAY:
         return var->a_val->nelts;
-    case HASH:
+    case TemplateVariable::HASH:
         return apr_hash_count(var->h_val);
     default:
         UNEXPECTED(0);
     }
 }
 
-TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *node)
+template<class ResponseWriterClass>
+typename TemplateExecutor<ResponseWriterClass>::variable *
+TemplateExecutor<ResponseWriterClass>::get_var(node *node)
 {
     // ϢޤλͤϤӤߤ硼
 
@@ -423,26 +436,26 @@ TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *node)
 
     switch (node->type) {
     case TemplateParser::IDENTIFIER:    // IDENTIFIER
-        var = h->vmap->at(node->i_val);
+        var = vmap_[node->i_val];
         break;
     case TemplateParser::ARRAY_REF:     // []
-        var = h->vmap->at(node->branch.left->i_val);
+        var = vmap_[node->branch.left->i_val];
         if (var == NULL) {
             break;
-        } else if (UNLIKELY(var->type != ARRAY)) {
+        } else if (UNLIKELY(var->type != TemplateVariable::ARRAY)) {
             throw "ɬפʾˤ¾ѿꤵƤޤ";
         }
 
         if (node->branch.right->type == TemplateParser::INTEGER) { // foo[var]
             var = *(reinterpret_cast<variable **>(var->a_val->elts) +
-                    calc_i_val(h, node->branch.right));
+                    calc_i_val(node->branch.right));
         } else if (node->branch.right->type == TemplateParser::HASH_REF) { // foo[var].baz
             var = *(reinterpret_cast<variable **>(var->a_val->elts) +
-                    calc_i_val(h, node->branch.right->branch.left));
+                    calc_i_val(node->branch.right->branch.left));
 
             if (var == NULL) {
                 break;
-            } else if (UNLIKELY(var->type != HASH)) {
+            } else if (UNLIKELY(var->type != TemplateVariable::HASH)) {
                 throw "Ϣɬפʾˤ¾ѿꤵƤޤ";
             }
             key = node->branch.right->branch.right->s_val;
@@ -451,14 +464,14 @@ TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *node)
         }
         break;
     case TemplateParser::HASH_REF:      // .
-        var = h->vmap->at(node->branch.left->i_val);
+        var = vmap_[node->branch.left->i_val];
         if (var == NULL) {
             break;
-        } else if (UNLIKELY(var->type != HASH)) {
+        } else if (UNLIKELY(var->type != TemplateVariable::HASH)) {
             throw "Ϣɬפʾˤ¾ѿꤵƤޤ";
         }
 
-        key = h->imap->at(node->branch.right->i_val);
+        key = imap_->at(node->branch.right->i_val);
 
         var = static_cast<variable *>(apr_hash_get(var->h_val, key,
                                                         APR_HASH_KEY_STRING));
@@ -476,51 +489,23 @@ TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *node)
     return var;
 }
 
-TemplateExecutor::variable *TemplateExecutor::create_variable(handle *h,
-                                                                     variable_type type)
-{
-    if (h->variable_pool == h->variable_pool_end) {
-        APR_PALLOC(h->variable_pool, variable *, h->pool, sizeof(variable)*VARIABLE_POOL_NUM);
-
-        h->variable_pool_end = h->variable_pool + VARIABLE_POOL_NUM;
-    }
-
-    variable *variable = h->variable_pool++;
-    variable->type = type;
-
-    return variable;
-}
-
-TemplateExecutor::scalar *TemplateExecutor::create_scalar(handle *h,
-                                                                 scalar_type type)
-{
-    if (h->scalar_pool == h->scalar_pool_end) {
-        APR_PALLOC(h->scalar_pool, scalar *, h->pool, sizeof(scalar)*SCALAR_POOL_NUM);
-
-        h->scalar_pool_end = h->scalar_pool + SCALAR_POOL_NUM;
-    }
-
-    scalar *scalar = h->scalar_pool++;
-    scalar->type = type;
-
-    return scalar;
-}
-
-void TemplateExecutor::print(handle *h, int i_val)
+template<class ResponseWriterClass>
+inline void TemplateExecutor<ResponseWriterClass>::print(int i_val)
 {
 #ifdef DEBUG_TEMPLATE
     cout << i_val;
 #else
-    ap_rputs(apr_itoa(h->pool, i_val), h->request);
+    print(apr_itoa(pool_, i_val));
 #endif
 }
 
-void TemplateExecutor::print(handle *h, const char *s_val)
+template<class ResponseWriterClass>
+inline void TemplateExecutor<ResponseWriterClass>::print(const char *s_val)
 {
 #ifdef DEBUG_TEMPLATE
     cout << s_val;
 #else
-    ap_rputs(s_val, h->request);
+    writer_.puts(s_val);
 #endif
 }
 
