@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.cpp 672 2005-09-13 13:27:42Z svn $
+ * $Id: TemplateLexer.cpp 914 2005-11-17 15:07:03Z svn $
  *****************************************************************************/
 
 #include "TemplateLexer.h"
@@ -172,7 +172,7 @@ void TemplateLexer::dump_token(token_vector::const_iterator start,
 {
     token_vector::const_iterator i;
 
-    for (i = start; i != end; i++) {
+    for (i = start; i != end; ++i) {
         TemplateLexer::print_token(*i);
     }
 }
@@ -184,7 +184,7 @@ void TemplateLexer::dump_token(token_vector *tvector)
 
 const char *TemplateLexer::get_token_type(token *token)
 {
-    for (apr_size_t i = 0; i < sizeof(token_type_list)/sizeof(token_type_str); i++) {
+    for (apr_size_t i = 0; i < sizeof(token_type_list)/sizeof(token_type_str); ++i) {
         if (token->type == token_type_list[i].type) {
             return token_type_list[i].str;
         }
@@ -579,7 +579,7 @@ int main(int argc, const char * const *argv)
         imap = lexer.get_ident_map();
 
         TemplateLexer::token_vector::iterator i;
-        for (i = tvector->begin(); i != tvector->end(); i++) {
+        for (i = tvector->begin(); i != tvector->end(); ++i) {
             TemplateLexer::print_token(*i, imap);
         }
 
