@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateParser.cpp 672 2005-09-13 13:27:42Z svn $
+ * $Id: TemplateParser.cpp 914 2005-11-17 15:07:03Z svn $
  *****************************************************************************/
 
 #include "TemplateParser.h"
@@ -143,7 +143,7 @@ apr_size_t TemplateParser::print_node(node *node)
 }
 
 const char *TemplateParser::get_node_type(node * const node)
-{    for (apr_size_t i = 0; i < sizeof(node_type_list)/sizeof(node_type_str); i++) {
+{    for (apr_size_t i = 0; i < sizeof(node_type_list)/sizeof(node_type_str); ++i) {
         if (node->type == node_type_list[i].type) {
             return node_type_list[i].str;
         }
