@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailWriter.cpp 704 2005-09-19 19:33:13Z svn $
+ * $Id: ThumbnailWriter.cpp 916 2005-11-20 15:30:59Z svn $
  *****************************************************************************/
 
 #include "ThumbnailWriter.h"
@@ -34,6 +34,7 @@
 #include "Auxiliary.h"
 #include "Misc.h"
 
+#include "apr_mmap.h"
 #include "apr_file_io.h"
 #include "apr_strings.h"
 
@@ -58,6 +59,12 @@
 #undef PACKAGE_TARNAME
 #undef PACKAGE_VERSION
 
+#ifdef SEGV_SAFE
+#include <unistd.h>
+#include <sys/types.h>
+#include <sys/wait.h>
+#endif
+
 #ifdef DEBUG
 #include <iostream>
 #endif
@@ -87,9 +94,10 @@ ThumbnailWriter::ThumbnailWriter(apr_pool_t *pool, const char *file_dir,
 
 }
 
-void ThumbnailWriter::write(const char *file_name)
+bool ThumbnailWriter::write(const char *file_name)
 {
     apr_pool_t *pool;
+    bool is_created = false;
 
     if (apr_pool_create(&pool, pool_) != APR_SUCCESS) {
         throw "γݤ˼Ԥޤ";
@@ -97,13 +105,20 @@ void ThumbnailWriter::write(const char *file_name)
 
     try {
 #ifdef HAVE_FFMPEG
-        if (!create_movie_thumb(pool, file_name)) {
+#ifdef SEGV_SAFE
+        is_created = create_movie_thumb_safe(pool, file_name);
+#else
+        is_created = create_movie_thumb(pool, file_name);
 #endif
-            create_image_thumb(pool, file_name);
-#ifdef HAVE_FFMPEG
+#endif
+
+        if (!is_created) {
+            is_created = create_image_thumb(pool, file_name);
         }
-#endif
+
         apr_pool_destroy(pool);
+
+        return is_created;
     } catch(const char *) {
         apr_pool_destroy(pool);
         throw;
@@ -118,13 +133,11 @@ const char *ThumbnailWriter::create_thumb_path(apr_pool_t *pool,
                        thumb_dir, "/", file_path, FILE_SUFFIX, NULL);
 }
 
-
 /******************************************************************************
  * private ᥽å
  *****************************************************************************/
 bool ThumbnailWriter::create_image_thumb(apr_pool_t *pool, const char *file_name)
 {
-
     try {
         apr_size_t read_size;
         void *file_buffer;
@@ -142,8 +155,8 @@ bool ThumbnailWriter::create_image_thumb(apr_pool_t *pool, const char *file_name
         }
 
         adjust_size(thumb_size);
-
         image.scale(thumb_size);
+
         image.write(create_thumb_path(pool, thumb_dir_, file_name));
 
         return true;
@@ -151,6 +164,8 @@ bool ThumbnailWriter::create_image_thumb(apr_pool_t *pool, const char *file_name
         throw e.what();
     } catch(exception &e) {
         throw e.what();
+    } catch(const char *) {
+        throw;
     }
 }
 
@@ -159,29 +174,57 @@ bool ThumbnailWriter::open_image_file(apr_pool_t *pool, const char *file_name,
 {
     UploadItem::header *header;
     apr_file_t *file;
-    apr_size_t read_size;
+    apr_mmap_t *file_map;
 
     UploadItemReader reader(pool, file_dir_);
-    header = reader.read(file_name, &file);
 
+    header = reader.read(file_name, &file, false);
     if (header->file_size > MAGICK_SIZE_LIMIT) {
         return false;
     }
 
-    APR_PALLOC(*file_buffer, void *, pool, header->file_size);
-
-    if ((apr_file_read_full(file, *file_buffer, header->file_size, &read_size) != APR_SUCCESS) ||
-        (read_size != header->file_size)) {
-        throw "åץɥեɤ߹ޤǤ";
+    if (apr_mmap_create(&file_map, file,
+                        sizeof(UploadItem::header), header->file_size,
+                        APR_MMAP_READ, pool) != APR_SUCCESS) {
+        throw "åץɥե mmap ˼Ԥޤ";
     }
-    apr_file_close(file);
 
+    APR_PALLOC(*file_buffer, void *, pool, header->file_size);
+    memcpy(*file_buffer, file_map->mm, header->file_size);
+
+    if (apr_mmap_delete(file_map) != APR_SUCCESS) {
+        throw "åץɥե munmap ˼Ԥޤ";
+    }
+
+    apr_file_close(file);
     *size = header->file_size;
 
     return true;
 }
 
 #ifdef HAVE_FFMPEG
+#ifdef SEGV_SAFE
+bool ThumbnailWriter::create_movie_thumb_safe(apr_pool_t *pool, const char *file_name)
+{
+    static const int SUCCEED    = 0;
+    static const int FAIL       = -1;
+
+    int status;
+
+    switch (fork()) {
+    case 0: // ҥץ
+        apr_pool_create(&pool, NULL);
+        exit(create_movie_thumb(pool, file_name) ? SUCCEED : FAIL);
+    case -1: // 顼
+        return false;
+    default: // ƥץ
+        wait(&status);
+
+        return WIFEXITED(status) && (WEXITSTATUS(status) == SUCCEED);
+    }
+}
+#endif
+
 bool ThumbnailWriter::create_movie_thumb(apr_pool_t *pool, const char *file_name)
 {
     list<Magick::Image> frame_list;
@@ -213,8 +256,8 @@ bool ThumbnailWriter::create_movie_thumb(apr_pool_t *pool, const char *file_name
                    codec_context->width, codec_context->height);
 
 
-    read_movie_frame(format_context, codec_context,frame, picture, video_index,
-                     FRAME_SAMPLE_SEC, FRAME_DELAY_SEC, FRAME_NUMBER, frame_list);
+    read_movie_frames(format_context, codec_context,frame, picture, video_index,
+                      FRAME_SAMPLE_SEC, FRAME_DELAY_SEC, FRAME_NUMBER, frame_list);
 
     writeImages(frame_list.begin(), frame_list.end(),
                 create_thumb_path(pool, thumb_dir_, file_name));
@@ -287,7 +330,7 @@ bool ThumbnailWriter::open_movie_context(apr_pool_t *pool, const char *file_path
     }
 
     *video_index = -1;
-    for (i = 0; i < (*format_context)->nb_streams; i++) {
+    for (i = 0; i < (*format_context)->nb_streams; ++i) {
         if ((*format_context)->streams[i]->codec.codec_type == CODEC_TYPE_VIDEO) {
             *video_index = i;
             break;
@@ -319,12 +362,12 @@ void ThumbnailWriter::close_movie_context(AVFormatContext *format_context,
     av_close_input_file(format_context);
 }
 
-void ThumbnailWriter::read_movie_frame(AVFormatContext *format_context,
-                                       AVCodecContext *codec_context,
-                                       AVFrame *frame, AVPicture *picture, int video_index,
-                                       double frame_sample, double frame_delay,
-                                       apr_size_t frame_number,
-                                       list<Magick::Image> &frame_list)
+void ThumbnailWriter::read_movie_frames(AVFormatContext *format_context,
+                                        AVCodecContext *codec_context,
+                                        AVFrame *frame, AVPicture *picture, int video_index,
+                                        double frame_sample, double frame_delay,
+                                        apr_size_t frame_number,
+                                        list<Magick::Image> &frame_list)
 {
     AVPacket packet;
     apr_size_t movie_fps;
@@ -375,7 +418,7 @@ void ThumbnailWriter::read_movie_frame(AVFormatContext *format_context,
 }
 #endif
 
-void ThumbnailWriter::adjust_size(Magick::Geometry &size) const
+void ThumbnailWriter::adjust_size(Magick::Geometry &size)
 {
     if ((size.width() <= WIDTH_LIMIT) && (size.height() <= HEIGHT_LIMIT)) {
         return;
