@@ -24,15 +24,12 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 684 2005-09-15 07:12:00Z svn $
+ * $Id: UploadItem.cpp 896 2005-10-23 19:31:04Z svn $
  *****************************************************************************/
 
 #include "UploadItem.h"
-#include "Auxiliary.h"
-#include "Misc.h"
 
 #include "apr_strings.h"
-#include "apr_time.h"
 
 #include <string>
 
@@ -61,10 +58,6 @@ const char UploadItem::TIME_FORMAT[]            = UITEM_TIME_FORMAT;
 const apr_size_t UploadItem::MAX_TIME_LENGTH    = UITEM_MAX_TIME_LENGTH;
 const apr_size_t UploadItem::TIME_ZONE_OFFSET   = UITEM_TIME_ZONE_OFFSET;
 
-#ifdef DEBUG_TEMPLATE
-#define ap_escape_html(pool, str) str
-#endif
-
 
 /******************************************************************************
  * public ᥽å
@@ -100,63 +93,6 @@ UploadItem::header *UploadItem::get_header() const
     return header_;
 }
 
-const char *UploadItem::get_file_path() const
-{
-    return file_path_;
-}
-
-const char *UploadItem::get_file_name() const
-{
-    return header_->file_name;
-}
-
-const char *UploadItem::get_file_digest() const
-{
-    return header_->file_digest;
-}
-
-const char *UploadItem::get_comment() const
-{
-    return header_->comment;
-}
-
-const char *UploadItem::get_remove_pass() const
-{
-    return header_->remove_pass;
-}
-
-const char *UploadItem::get_download_pass() const
-{
-    return header_->download_pass;
-}
-
-const char *UploadItem::get_file_size() const
-{
-    return size_str(pool_, header_->file_size);
-}
-
-const char *UploadItem::get_file_mime() const
-{
-    return header_->file_mime;
-}
-
-const char *UploadItem::get_time() const
-{
-    apr_time_exp_t time_exp;
-    char *time_str;
-    apr_size_t size;
-
-    APR_PALLOC(time_str, char *, pool_, sizeof(char)*MAX_TIME_LENGTH);
-
-    if (time_str == NULL) {
-        throw "ɽΤΥݤ˼Ԥޤ";
-    }
-    apr_time_exp_tz(&time_exp, header_->time, TIME_ZONE_OFFSET);
-    apr_strftime(time_str, &size, MAX_TIME_LENGTH, TIME_FORMAT, &time_exp);
-
-    return time_str;
-}
-
 #ifdef DEBUG
 void UploadItem::dump_header(header *header)
 {
