@@ -24,11 +24,12 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemCreator.cpp 699 2005-09-18 10:16:51Z svn $
+ * $Id: UploadItemCreator.cpp 913 2005-10-29 18:33:54Z svn $
  *****************************************************************************/
 
 #include "UploadItemCreator.h"
 #include "CharCodeConverter.h"
+#include "Auxiliary.h"
 #include "Misc.h"
 
 #ifdef DEBUG
@@ -40,7 +41,7 @@
  * public ᥽å
  *****************************************************************************/
 UploadItem::header *UploadItemCreator::create_header(apr_pool_t *pool,
-                                                     UploadParser::query_map *qmap,
+                                                     RFC1867Data::query_map *qmap,
                                                      const char **tmp_path)
 {
     UploadItem::header *data;
@@ -74,15 +75,15 @@ UploadItem::header *UploadItemCreator::create_header(apr_pool_t *pool,
  * private ᥽å
  *****************************************************************************/
 void UploadItemCreator::validate_query(apr_pool_t *pool,
-                                       UploadParser::query_map *qmap)
+                                       RFC1867Data::query_map *qmap)
 {
     const unsigned char *code_pat;
-    const char *file_name;
 
     // MEMO:
     // - ե륵 0 ξϡ顼Ф
     // - ȤѥɤˤĤƤϡȤǤ⥨顼Фʤ
     // - ե̾MIME סȤ HTML פ롥
+    // - ν֤ϡʸѴ -> HTML  -> Ĺåν
 
     if (qmap->count(UploadItem::CODE_PAT_PARAM) != 1) {
         throw "ʸȽѥλ꤬Ǥ";
@@ -93,15 +94,37 @@ void UploadItemCreator::validate_query(apr_pool_t *pool,
     if (qmap->count(UploadItem::FILE_PARAM) != 1) {
         throw "եλ꤬Ǥ";
     }
-    if (((*qmap)[UploadItem::FILE_PARAM].type != UploadParser::FILE) ||
-               ((*qmap)[UploadItem::FILE_PARAM].file.size == 0)) {
+    validate_file(pool, (*qmap)[UploadItem::FILE_PARAM], code_pat);
+
+    if (qmap->count(UploadItem::COMMENT_PARAM) != 1) {
+        throw "Ȥλ꤬Ǥ";
+    }
+    validate_comment(pool, (*qmap)[UploadItem::COMMENT_PARAM], code_pat);
+
+    if (qmap->count(UploadItem::DOWNLOAD_PASS_PARAM) != 1) {
+        throw "ɥѥɤλ꤬Ǥ";
+    }
+    validate_download_pass(pool, (*qmap)[UploadItem::DOWNLOAD_PASS_PARAM]);
+
+    if (qmap->count(UploadItem::REMOVE_PASS_PARAM) != 1) {
+        throw "ѥɤλ꤬Ǥ";
+    }
+    validate_remove_pass(pool, (*qmap)[UploadItem::REMOVE_PASS_PARAM]);
+}
+
+void UploadItemCreator::validate_file(apr_pool_t *pool, content& content,
+                                      const unsigned char *code_pat)
+{
+    const char *file_name;
+
+    convert_code(pool, content.text, code_pat);
+    escape_html(pool, content.text);
+
+    if ((content.type != RFC1867Data::FILE) || (content.file.size == 0)) {
         throw "ե뤬Ǥ";
     }
 
-    convert_code(pool, (*qmap)[UploadItem::FILE_PARAM].text, code_pat);
-    escape_html(pool, (*qmap)[UploadItem::FILE_PARAM].text);
-
-    file_name = (*qmap)[UploadItem::FILE_PARAM].file.name.c_str();
+    file_name = content.file.name.c_str();
 
     if (strlen(file_name) >= UploadItem::MAX_FILE_NAME_LENGTH) {
         throw "ե̾Ĺޤ";
@@ -114,42 +137,58 @@ void UploadItemCreator::validate_query(apr_pool_t *pool,
         }
     } while (*(++file_name) != '\0');
 
-
-    if ((*qmap)[UploadItem::FILE_PARAM].file.mime.length() >= UploadItem::MAX_FILE_MIME_LENGTH) {
+    escape_html(pool, content.file.mime);
+    if (content.file.mime.length() >= UploadItem::MAX_FILE_MIME_LENGTH) {
         throw "ե MIME Type Ĺޤ";
     }
-    escape_html(pool, (*qmap)[UploadItem::FILE_PARAM].file.mime);
+}
 
-    if (qmap->count(UploadItem::COMMENT_PARAM) != 1) {
-        throw "Ȥλ꤬Ǥ";
-    }
+void UploadItemCreator::validate_comment(apr_pool_t *pool, content& content,
+                                         const unsigned char *code_pat)
+{
+    convert_code(pool, content.text, code_pat);
+    escape_html(pool, content.text);
 
-    convert_code(pool, (*qmap)[UploadItem::COMMENT_PARAM].text, code_pat);
-    escape_html(pool, (*qmap)[UploadItem::COMMENT_PARAM].text);
-
-    if (((*qmap)[UploadItem::COMMENT_PARAM].type != UploadParser::TEXT) ||
-               ((*qmap)[UploadItem::COMMENT_PARAM].text.length() >= UploadItem::MAX_COMMENT_LENGTH)) {
+    if ((content.type != RFC1867Data::TEXT) ||
+        (content.text.length() >= UploadItem::MAX_COMMENT_LENGTH)) {
         throw "ȤĹޤ";
     }
+}
 
-    if (qmap->count(UploadItem::DOWNLOAD_PASS_PARAM) != 1) {
-        throw "ɥѥɤλ꤬Ǥ";
-    } else if (((*qmap)[UploadItem::DOWNLOAD_PASS_PARAM].type != UploadParser::TEXT) ||
-               ((*qmap)[UploadItem::DOWNLOAD_PASS_PARAM].text.length() >= UploadItem::MAX_DOWNLOAD_PASS_LENGTH)) {
+void UploadItemCreator::validate_download_pass(apr_pool_t *pool, content& content)
+{
+    const char *download_pass;
+
+    if ((content.type != RFC1867Data::TEXT) ||
+        (content.text.length() >= UploadItem::MAX_DOWNLOAD_PASS_LENGTH)) {
         throw "ɥѥɤĹޤ";
     }
 
-    if (qmap->count(UploadItem::REMOVE_PASS_PARAM) != 1) {
-        throw "ѥɤλ꤬Ǥ";
-    } else if (((*qmap)[UploadItem::REMOVE_PASS_PARAM].type != UploadParser::TEXT) ||
-               ((*qmap)[UploadItem::REMOVE_PASS_PARAM].text.length() >= UploadItem::MAX_REMOVE_PASS_LENGTH)) {
+    download_pass = content.file.name.c_str();
+
+    do {
+        if ((*download_pass == '<') || (*download_pass == '>') ||
+            (*download_pass == '"') || (*download_pass == '\'') ||
+            (*download_pass == '\r') || (*download_pass == '\n') ||
+            (*download_pass == '\\')) {
+            throw "ɥѥɤ"
+                  "<ס>ס\"ס'ס\\rס\\nס\\"
+                  "ϻȤޤ";
+        }
+    } while (*(++download_pass) != '\0');
+}
+
+void UploadItemCreator::validate_remove_pass(apr_pool_t *pool, content& content)
+{
+    if ((content.type != RFC1867Data::TEXT) ||
+        (content.text.length() >= UploadItem::MAX_REMOVE_PASS_LENGTH)) {
         throw "ѥɤĹޤ";
     }
 }
 
 void UploadItemCreator::escape_html(apr_pool_t *pool, string &str)
 {
-    str.assign(ap_escape_html(pool, str.c_str()));
+    str.assign(::escape_html(pool, str.c_str()));
 }
 
 void UploadItemCreator::convert_code(apr_pool_t *pool, string &str,
@@ -160,8 +199,8 @@ void UploadItemCreator::convert_code(apr_pool_t *pool, string &str,
 
 void UploadItemCreator::set_file_data(apr_pool_t *pool,
                                       UploadItem::header *data,
-                                      UploadParser::file_content& file,
-                                      UploadParser::query_map *qmap)
+                                      RFC1867Data::file_content& file,
+                                      RFC1867Data::query_map *qmap)
 {
     strncpy(data->file_name, file.name.c_str(), UploadItem::MAX_FILE_NAME_LENGTH-1);
     strncpy(data->file_mime, file.mime.c_str(), UploadItem::MAX_FILE_MIME_LENGTH-1);
