@@ -24,15 +24,16 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 685 2005-09-15 07:18:18Z svn $
+ * $Id: UploadItemList.cpp 895 2005-10-23 18:50:50Z svn $
  *****************************************************************************/
 
 #include "UploadItemList.h"
-#include "TemplateVariableCreator.h"
+#include "UploadVariableCreator.h"
 #include "Misc.h"
 
 #include "apr_strings.h"
 #include "apr_tables.h"
+#include "apr_mmap.h"
 #define APR_WANT_STRFUNC
 #include "apr_want.h"
 
@@ -66,7 +67,7 @@ UploadItemList::UploadItemList(apr_pool_t *pool,
       twriter_(pool, file_dir, thumb_dir),
 #endif
       total_size_(0),
-      mtime_(0)
+      revision_(0)
 {
 
 }
@@ -80,7 +81,7 @@ void UploadItemList::add(const char *file_path, bool is_new)
     header = reader_.read(file_path, &file);
     apr_file_close(file);
 
-    // pool_ ʤ data_pool_ ȤȤޤ
+    // pool_ Ȥdata_pool_ ȤȤޤ
     APR_PALLOC(info, item_info *, pool_, sizeof(item_info));
     info->file_path = static_cast<const char *>(apr_pstrdup(pool_, file_path));
     info->header = header;
@@ -123,26 +124,14 @@ apr_time_t UploadItemList::get_mtime() const
     return mtime_;
 }
 
-void UploadItemList::update_mtime()
+apr_size_t UploadItemList::get_revision() const
 {
-    apr_finfo_t info;
-
-    if (UNLIKELY(apr_stat(&info, file_dir_, APR_FINFO_MTIME, pool_) != APR_SUCCESS)) {
-        return;
-    }
-
-    mtime_ =  info.mtime;
+    return revision_;
 }
 
-bool UploadItemList::is_need_update(apr_pool_t *pool) const
+void UploadItemList::set_revision(apr_size_t revision)
 {
-    apr_finfo_t info;
-
-    if (UNLIKELY(apr_stat(&info, file_dir_, APR_FINFO_MTIME, pool) != APR_SUCCESS)) {
-        return false;
-    }
-
-    return mtime_ != info.mtime;
+    revision_ = revision;
 }
 
 void UploadItemList::remove(const char *file_path, const char *password)
@@ -151,7 +140,7 @@ void UploadItemList::remove(const char *file_path, const char *password)
 
     load_file();
 
-    for (i = begin(); i != end(); i++) {
+    for (i = begin(); i != end(); ++i) {
         if (strcmp((*i)->file_path, file_path) == 0) {
             break;
         }
@@ -168,53 +157,52 @@ void UploadItemList::remove(const char *file_path, const char *password)
     remove(*i);
 
     write_cache();
-    update_mtime();
 }
 
-TemplateExecutor::variable *UploadItemList::to_varray(apr_pool_t *pool,
+TemplateVariable::variable *UploadItemList::to_varray(apr_pool_t *pool,
                                                       apr_size_t start,
                                                       apr_size_t size) const
 {
     apr_array_header_t *array = apr_array_make(pool, static_cast<int>(size),
-                                               static_cast<int>(sizeof(TemplateExecutor::variable *)));
+                                               static_cast<int>(sizeof(TemplateVariable::variable *)));
     item_iterator i = begin();
-    TemplateExecutor::variable **var;
+    TemplateVariable::variable **var;
     UploadItem item(pool);
 
     for (apr_size_t j = 0; (j < start) && (i != end()); j++) {
         i++;
     }
 
-    for (apr_size_t j = 0; (j < size) && (i != end()); j++, i++) {
+    for (apr_size_t j = 0; (j < size) && (i != end()); j++, ++i) {
         item.set_data((*i)->file_path, (*i)->header);
 
-        var = static_cast<TemplateExecutor::variable **>(apr_array_push(array));
-        *var = TemplateVariableCreator::create(pool, &item);
+        var = static_cast<TemplateVariable::variable **>(apr_array_push(array));
+        *var = UploadVariableCreator::create(pool, &item);
     }
 
-    return TemplateVariableCreator::create(pool, array);
+    return UploadVariableCreator::create(pool, array);
 }
 
-TemplateExecutor::variable *UploadItemList::to_thumb_varray(apr_pool_t *pool,
+TemplateVariable::variable *UploadItemList::to_thumb_varray(apr_pool_t *pool,
                                                             apr_size_t start,
                                                             apr_size_t size) const
 {
     apr_array_header_t *array = apr_array_make(pool, static_cast<int>(size),
-                                               static_cast<int>(sizeof(TemplateExecutor::variable *)));
+                                               static_cast<int>(sizeof(TemplateVariable::variable *)));
 
     thumb_iterator i = tlist_.begin();
-    TemplateExecutor::variable **var;
+    TemplateVariable::variable **var;
 
     for (apr_size_t j = 0; (j < start) && (i != tlist_.end()); j++) {
         i++;
     }
 
-    for (apr_size_t j = 0; (j < size) && (i != tlist_.end()); j++, i++) {
-         var = static_cast<TemplateExecutor::variable **>(apr_array_push(array));
-         *var = TemplateVariableCreator::create(pool, (*i).c_str());
+    for (apr_size_t j = 0; (j < size) && (i != tlist_.end()); j++, ++i) {
+        var = static_cast<TemplateVariable::variable **>(apr_array_push(array));
+        *var = UploadVariableCreator::create(pool, (*i).c_str());
     }
 
-    return TemplateVariableCreator::create(pool, array);
+    return UploadVariableCreator::create(pool, array);
 }
 
 UploadItemList::item_info **UploadItemList::to_array(apr_pool_t *pool,
@@ -232,7 +220,7 @@ UploadItemList::item_info **UploadItemList::to_array(apr_pool_t *pool,
     APR_PCALLOC(item_list, item_info **, pool, sizeof(item_info *)*(size+1));
 
     item = item_list;
-    for (apr_size_t j = 0; (j < size) && (i != end()); j++, i++) {
+    for (apr_size_t j = 0; (j < size) && (i != end()); j++, ++i) {
         *item = *i;
 
         item++;
@@ -268,7 +256,7 @@ void UploadItemList::dump_list(UploadItemList *item_list)
 {
     item_iterator i;
 
-    for (i = item_list->begin(); i != item_list->end(); i++) {
+    for (i = item_list->begin(); i != item_list->end(); ++i) {
         UploadItem::dump_header((*i)->header);
     }
 }
@@ -332,7 +320,7 @@ void UploadItemList::load_file_by_item()
     apr_finfo_t info;
 
     if (apr_dir_open(&dir, file_dir_, pool_) != APR_SUCCESS) {
-        throw "åץɥեΥꥹȤɤ߹ޤǤ";
+        throw "Failed to open FileDirectory.";
     }
 
     try {
@@ -376,7 +364,7 @@ void UploadItemList::load_file_by_cache()
         throw;
     }
 
-    for (i = 0; i < number; i++) {
+    for (i = 0; i < number; ++i) {
         APR_PALLOC(info, item_info *, data_pool_, sizeof(item_info));
 
         info->file_path = path;
@@ -435,9 +423,9 @@ void UploadItemList::add_new(item_info *info)
 
 #ifdef MAKE_THUMBNAIL
     try {
-        twriter_.write(info->file_path);
-
-        tlist_.push_front(info->file_path);
+        if (twriter_.write(info->file_path)) {
+            tlist_.push_front(info->file_path);
+        }
     } catch(const char *) {
         // ̵
     }
@@ -455,7 +443,6 @@ void UploadItemList::add_new(item_info *info)
     }
 
     write_cache();
-    update_mtime();
 }
 
 UploadItemList::item_iterator UploadItemList::begin() const
@@ -565,7 +552,7 @@ void UploadItemList::read_path_cache(apr_pool_t *tmp_pool, char **paths,
     if (apr_file_open(&cache_file, path_cache_path_,
                       APR_READ|APR_BINARY,
                       APR_OS_DEFAULT, tmp_pool) != APR_SUCCESS) {
-        throw "ƥΥåե򳫤ޤǤ";
+        throw "åե򳫤ޤǤ";
     }
 
     if (apr_file_info_get(&info, APR_FINFO_SIZE, cache_file) != APR_SUCCESS) {
@@ -575,7 +562,7 @@ void UploadItemList::read_path_cache(apr_pool_t *tmp_pool, char **paths,
     if (apr_mmap_create(&file_map, cache_file,
                         0, static_cast<apr_size_t>(info.size),
                         APR_MMAP_READ, tmp_pool) != APR_SUCCESS) {
-        throw "åե map ˼Ԥޤ";
+        throw "åե mmap ˼Ԥޤ";
     }
 
     APR_PCALLOC(*paths, char *, data_pool_, static_cast<apr_size_t>(info.size+1));
@@ -594,7 +581,7 @@ void UploadItemList::read_path_cache(apr_pool_t *tmp_pool, char **paths,
     }
 
     if (apr_mmap_delete(file_map) != APR_SUCCESS) {
-        throw "åե unmap ˼Ԥޤ";
+        throw "åե munmap ˼Ԥޤ";
     }
 
     apr_file_close(cache_file);
@@ -613,7 +600,7 @@ void UploadItemList::read_header_cache(apr_pool_t *tmp_pool,
     if (apr_file_open(&cache_file, header_cache_path_,
                       APR_READ|APR_BINARY,
                       APR_OS_DEFAULT, tmp_pool) != APR_SUCCESS) {
-        throw "ƥΥåե򳫤ޤǤ";
+        throw "åե򳫤ޤǤ";
     }
 
     if (apr_file_info_get(&info, APR_FINFO_SIZE, cache_file) != APR_SUCCESS) {
@@ -629,7 +616,7 @@ void UploadItemList::read_header_cache(apr_pool_t *tmp_pool,
     if (apr_mmap_create(&file_map, cache_file,
                         0, static_cast<apr_size_t>(info.size),
                         APR_MMAP_READ, tmp_pool) != APR_SUCCESS) {
-        throw "åե map ˼Ԥޤ";
+        throw "åե mmap ˼Ԥޤ";
     }
 
     APR_PALLOC(*headers, UploadItem::header *, data_pool_, static_cast<apr_size_t>(info.size));
@@ -637,7 +624,7 @@ void UploadItemList::read_header_cache(apr_pool_t *tmp_pool,
     memcpy(*headers, file_map->mm, static_cast<apr_size_t>(info.size));
 
     if (apr_mmap_delete(file_map) != APR_SUCCESS) {
-        throw "åե unmap ˼Ԥޤ";
+        throw "åե munmap ˼Ԥޤ";
     }
 
     apr_file_close(cache_file);
@@ -655,6 +642,8 @@ void UploadItemList::write_cache()
     write_path_cache(tmp_pool);
 
     apr_pool_destroy(tmp_pool);
+
+    update_mtime();
 }
 
 void UploadItemList::write_path_cache(apr_pool_t *tmp_pool)
@@ -665,7 +654,7 @@ void UploadItemList::write_path_cache(apr_pool_t *tmp_pool)
 
     tmp_cache_path = get_tmp_path_cache_path(tmp_pool, &cache_file);
 
-    for (i = begin(); i != end(); i++) {
+    for (i = begin(); i != end(); ++i) {
         apr_file_printf(cache_file, "%s%c",
                         (*i)->file_path, PATH_CACHE_DELIMITER);
     }
@@ -705,7 +694,7 @@ void UploadItemList::write_header_cache(apr_pool_t *tmp_pool)
         }
 
         header = static_cast<UploadItem::header *>(file_map->mm);
-        for (i = begin(); i != end(); i++) {
+        for (i = begin(); i != end(); ++i) {
             memcpy(header++, (*i)->header, sizeof(UploadItem::header));
         }
 
@@ -728,6 +717,11 @@ void UploadItemList::sort()
     }
 }
 
+void UploadItemList::update_mtime()
+{
+    mtime_ =  apr_time_now();
+}
+
 
 /******************************************************************************
  * ƥ
