@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemWriter.cpp 676 2005-09-14 14:43:48Z svn $
+ * $Id: UploadItemWriter.cpp 731 2005-09-24 19:35:03Z svn $
  *****************************************************************************/
 
 #include "UploadItemWriter.h"
@@ -122,12 +122,6 @@ static const apr_size_t  BUFSIZE        = 256;
 static const char FILE_DIR[]            = "/tmp";
 static const char CONTENT_TYPE_TMPL[]   = "multipart/form-data; boundary=%s";
 
-// ߡ
-char *ap_escape_html(apr_pool_t *pool, const char *str)
-{
-    return const_cast<char *>(str);
-}
-
 void usage(const char *prog_name)
 {
     cerr << "Usage: " << prog_name << " <INPUT>" << endl;
