@@ -24,26 +24,23 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 696 2005-09-17 14:41:55Z svn $
+ * $Id: UploaderConfig.cpp 914 2005-11-17 15:07:03Z svn $
  *****************************************************************************/
 
 #define __STDC_CONSTANT_MACROS
 
-#include "mod_uploader_data.h"
-
 #include "UploaderConfig.h"
 #include "Misc.h"
 
+#include "apr_mmap.h"
 #include "apr_strings.h"
 
+#define DESTROY(pool) if (pool != NULL) { apr_pool_destroy(pool); pool = NULL;}
+
 #ifdef DEBUG
 #include <iostream>
 #endif
 
-#undef DELETE
-#define DELETE(ptr) if (ptr != NULL) { delete ptr; ptr = NULL;}
-#define DESTROY(pool) if (pool != NULL) { apr_pool_destroy(pool); pool = NULL;}
-
 const apr_uint64_t UploaderConfig::TOTAL_FILE_SIZE_LIMIT= 1*1024*1024*1024;
 const apr_size_t UploaderConfig::TOTAL_FILE_NUMBER_LIMIT= 1000;
 const apr_size_t UploaderConfig::MAX_FORM_FILE_SIZE     = 100*1024*1024;
@@ -52,11 +49,6 @@ const apr_size_t UploaderConfig::MAX_FORM_ITEM_NUMBER   = 5;
 const apr_size_t UploaderConfig::PER_PAGE_ITEM_NUMBER   = 50;
 const apr_size_t UploaderConfig::ITEM_RELOAD_THRESHOLD  = 10;
 
-static apr_status_t finalize_config(void *data);
-#if APR_HAS_THREADS
-static apr_status_t finalize_lock(void *data);
-#endif
-
 
 /******************************************************************************
  * public ᥽å
@@ -66,7 +58,6 @@ UploaderConfig::UploaderConfig()
       file_dir(NULL),
       thumb_dir(NULL),
       tmp_dir(NULL),
-      magick_dir(NULL),
       view_tmpl_path(NULL),
       progress_tmpl_path(NULL),
       download_tmpl_path(NULL),
@@ -78,8 +69,6 @@ UploaderConfig::UploaderConfig()
       per_page_item_number(PER_PAGE_ITEM_NUMBER),
       remove_item_number(0),
       item_list(NULL),
-      texecutor(NULL),
-      uparser(NULL),
       view_tmpl_(NULL),
       view_tmpl_pool_(NULL),
       progress_tmpl_(NULL),
@@ -90,11 +79,8 @@ UploaderConfig::UploaderConfig()
       thumb_tmpl_pool_(NULL),
       error_tmpl_(NULL),
       error_tmpl_pool_(NULL),
+      pool_(NULL),
       list_pool_(NULL),
-      glock_(NULL),
-#if APR_HAS_THREADS
-      lock_(NULL),
-#endif
       is_init_(false)
 {
 
@@ -105,41 +91,17 @@ UploaderConfig::~UploaderConfig()
     finalize();
 }
 
-void UploaderConfig::init(request_rec *r)
-{
-    if (LIKELY(is_init_)) {
-        return update_list(r->pool);
-    }
-
-    pool_ = r->server->process->pool;
-
-    glock_ = (static_cast<sconfig *>(ap_get_module_config(r->server->module_config,
-                                                          &uploader_module)))->upload_lock;
-
-    global_lock();
-    try {
-        if (!is_init_) {
-            exec_init();
-        }
-        global_unlock();
-    } catch(const char *) {
-        global_unlock();
-        throw;
-    }
-}
-
 void UploaderConfig::finalize()
 {
-    DELETE(uparser);
-    DELETE(texecutor);
-    DELETE(item_list);
-    DELETE(view_tmpl_);
-    DELETE(progress_tmpl_);
-    DELETE(download_tmpl_);
+    delete item_list;
+
+    delete view_tmpl_;
+    delete progress_tmpl_;
+    delete download_tmpl_;
 #ifdef MAKE_THUMBNAIL
-    DELETE(thumb_tmpl_);
+    delete thumb_tmpl_;
 #endif
-    DELETE(error_tmpl_);
+    delete error_tmpl_;
 
     DESTROY(list_pool_);
     DESTROY(view_tmpl_pool_);
@@ -151,7 +113,7 @@ void UploaderConfig::finalize()
     DESTROY(error_tmpl_pool_);
 }
 
-UploaderConfig::page_template *UploaderConfig::get_view_template(apr_pool_t *pool)
+page_template *UploaderConfig::get_view_template(apr_pool_t *pool)
 {
     if (UNLIKELY(get_mtime(pool, view_tmpl_path) > view_tmpl_->mtime)) {
         load_template(pool, &view_tmpl_pool_, view_tmpl_path, view_tmpl_);
@@ -160,7 +122,7 @@ UploaderConfig::page_template *UploaderConfig::get_view_template(apr_pool_t *poo
     return view_tmpl_;
 }
 
-UploaderConfig::page_template *UploaderConfig::get_progress_template(apr_pool_t *pool)
+page_template *UploaderConfig::get_progress_template(apr_pool_t *pool)
 {
     if (UNLIKELY(get_mtime(pool, progress_tmpl_path) > progress_tmpl_->mtime)) {
         load_template(pool, &progress_tmpl_pool_, progress_tmpl_path, progress_tmpl_);
@@ -169,7 +131,7 @@ UploaderConfig::page_template *UploaderConfig::get_progress_template(apr_pool_t
     return progress_tmpl_;
 }
 
-UploaderConfig::page_template *UploaderConfig::get_download_template(apr_pool_t *pool)
+page_template *UploaderConfig::get_download_template(apr_pool_t *pool)
 {
     if (UNLIKELY(get_mtime(pool, download_tmpl_path) > download_tmpl_->mtime)) {
         load_template(pool, &download_tmpl_pool_, download_tmpl_path, download_tmpl_);
@@ -178,7 +140,7 @@ UploaderConfig::page_template *UploaderConfig::get_download_template(apr_pool_t
     return download_tmpl_;
 }
 
-UploaderConfig::page_template *UploaderConfig::get_thumb_template(apr_pool_t *pool)
+page_template *UploaderConfig::get_thumb_template(apr_pool_t *pool)
 {
     if (UNLIKELY(get_mtime(pool, thumb_tmpl_path) > thumb_tmpl_->mtime)) {
         load_template(pool, &thumb_tmpl_pool_, thumb_tmpl_path, thumb_tmpl_);
@@ -187,7 +149,7 @@ UploaderConfig::page_template *UploaderConfig::get_thumb_template(apr_pool_t *po
     return thumb_tmpl_;
 }
 
-UploaderConfig::page_template *UploaderConfig::get_error_template(apr_pool_t *pool)
+page_template *UploaderConfig::get_error_template(apr_pool_t *pool)
 {
     if (UNLIKELY(get_mtime(pool, error_tmpl_path) > error_tmpl_->mtime)) {
         load_template(pool, &error_tmpl_pool_, error_tmpl_path, error_tmpl_);
@@ -206,84 +168,10 @@ UploadItemWriter *UploaderConfig::get_uwriter(apr_pool_t *pool)
     return new UploadItemWriter(pool, file_dir);
 }
 
-void UploaderConfig::read_lock()
-{
-    apr_status_t status = APR_SUCCESS;
-
-#if APR_HAS_THREADS
-#ifdef LOCK_TYPE_MUTEX
-    status = apr_thread_mutex_lock(lock_);
-#else
-    status = apr_thread_rwlock_rdlock(lock_);
-#endif
-#endif
-
-    if (UNLIKELY(status != APR_SUCCESS)) {
-        throw "read_lock() failed..";
-    }
-}
-
-void UploaderConfig::read_unlock()
-{
-    apr_status_t status = APR_SUCCESS;
-
-#if APR_HAS_THREADS
-#ifdef LOCK_TYPE_MUTEX
-    status = apr_thread_mutex_unlock(lock_);
-#else
-    status = apr_thread_rwlock_unlock(lock_);
-#endif
-#endif
-
-    if (UNLIKELY(status != APR_SUCCESS)) {
-        throw "read_unlock() failed. ";
-    }
-}
-
-void UploaderConfig::gwrite_lock()
-{
-    write_lock();
-    global_lock();
-}
-
-
-void UploaderConfig::gwrite_unlock()
-{
-    write_unlock();
-    global_unlock();
-}
-
 
 /******************************************************************************
- * private ᥽å
+ * protected ᥽å
  *****************************************************************************/
-void UploaderConfig::exec_init()
-{
-    validate();
-
-#if APR_HAS_THREADS
-    init_lock();
-#endif
-    load_list();
-
-    view_tmpl_      = new page_template();
-    progress_tmpl_  = new page_template();
-    download_tmpl_  = new page_template();
-#ifdef MAKE_THUMBNAIL
-    thumb_tmpl_     = new page_template();
-#endif
-    error_tmpl_     = new page_template();
-
-    texecutor       = new TemplateExecutor();
-    uparser         = new UploadParser(tmp_dir, MAX_FORM_TEXT_SIZE,
-                                       max_file_size, MAX_FORM_ITEM_NUMBER,
-                                       sizeof(UploadItem::header));
-
-    apr_pool_cleanup_register(pool_, this, apr_pool_cleanup_null, finalize_config);
-
-    is_init_ = true;
-}
-
 void UploaderConfig::validate()
 {
     if (file_dir            == NULL) throw "FileDirectory is not specified.";
@@ -298,26 +186,20 @@ void UploaderConfig::validate()
     if (error_tmpl_path     == NULL) throw "ErrorTemplateFile is not specified.";
 }
 
-#if APR_HAS_THREADS
-void UploaderConfig::init_lock()
+void UploaderConfig::init_template()
 {
-#ifdef LOCK_TYPE_MUTEX
-    if (apr_thread_mutex_create(&lock_, APR_THREAD_MUTEX_DEFAULT, pool_) != APR_SUCCESS) {
-        throw "Can not create thread mutex.";
-    }
-#else
-    if (apr_thread_rwlock_create(&lock_, pool_) != APR_SUCCESS) {
-        throw "Can not create rwlock.";
-    }
+    view_tmpl_      = new page_template();
+    progress_tmpl_  = new page_template();
+    download_tmpl_  = new page_template();
+#ifdef MAKE_THUMBNAIL
+    thumb_tmpl_     = new page_template();
 #endif
-
-    apr_pool_cleanup_register(pool_, lock_, apr_pool_cleanup_null, finalize_lock);
+    error_tmpl_     = new page_template();
 }
-#endif
 
-void UploaderConfig::load_list()
+void UploaderConfig::load_list(apr_size_t revision)
 {
-    DELETE(item_list);
+    delete item_list;
     DESTROY(list_pool_);
 
     if (apr_pool_create(&list_pool_, pool_) != APR_SUCCESS) {
@@ -326,68 +208,10 @@ void UploaderConfig::load_list()
 
     item_list = UploadItemList::load(list_pool_, file_dir, thumb_dir,
                                      total_file_number_limit, total_file_size_limit);
+    item_list->set_revision(revision);
     remove_item_number = 0;
 }
 
-void UploaderConfig::update_list(apr_pool_t *pool)
-{
-    if (LIKELY(!item_list->is_need_update(pool) &&
-               (remove_item_number != ITEM_RELOAD_THRESHOLD))) {
-        return;
-    }
-
-    try {
-        gwrite_lock();
-
-        load_list();
-
-        gwrite_unlock();
-    } catch(const char *) {
-        gwrite_unlock();
-        throw;
-    }
-}
-
-void UploaderConfig::write_lock()
-{
-    apr_status_t status = APR_SUCCESS;
-
-#if APR_HAS_THREADS
-#ifdef LOCK_TYPE_MUTEX
-    status = apr_thread_mutex_lock(lock_);
-#else
-    status = apr_thread_rwlock_wrlock(lock_);
-#endif
-#endif
-
-    if (UNLIKELY(status != APR_SUCCESS)) {
-        throw "write_lock() failed.";
-    }
-}
-
-void UploaderConfig::write_unlock()
-{
-    read_unlock();
-}
-
-void UploaderConfig::global_lock()
-{
-    if (UNLIKELY(apr_global_mutex_lock(glock_) != APR_SUCCESS)) {
-        throw "global_lock() failed.";
-    }
-}
-
-void UploaderConfig::global_unlock()
-{
-    // åץɥեιǥ쥯ȥ mtime ˴ŤȽ
-    // Ƥ뤱ɡUNIX Ǥ mtime ñ̤٤ʤΤɬס:-)
-    apr_sleep(APR_USEC_PER_SEC);
-
-    if (UNLIKELY(apr_global_mutex_unlock(glock_) != APR_SUCCESS)) {
-        throw "global_unlock() failed.";
-    }
-}
-
 void UploaderConfig::load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
                                    const char *template_path, page_template *tmpl)
 {
@@ -410,7 +234,7 @@ void UploaderConfig::load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
             throw "ƥץ졼Ȥ mmap ˼Ԥޤ";
         }
 
-        DELETE(tmpl->imap);
+        delete tmpl->imap;
         DESTROY(*tmpl_pool);
 
         if (apr_pool_create(tmpl_pool, pool_) != APR_SUCCESS) {
@@ -451,38 +275,6 @@ apr_time_t UploaderConfig::get_mtime(apr_pool_t *pool, const char *path)
 }
 
 
-/******************************************************************************
- * Хåؿ
- *****************************************************************************/
-apr_status_t finalize_config(void *data)
-{
-    UploaderConfig *config;
-
-    config = static_cast<UploaderConfig *>(data);
-    config->finalize();
-
-    return APR_SUCCESS;
-}
-
-#if APR_HAS_THREADS
-apr_status_t finalize_lock(void *data)
-{
-#ifdef LOCK_TYPE_MUTEX
-    apr_thread_mutex_t *lock;
-
-    lock = static_cast<apr_thread_mutex_t *>(data);
-    apr_thread_mutex_destroy(lock);
-#else
-    apr_thread_rwlock_t *lock;
-
-    lock = static_cast<apr_thread_rwlock_t *>(data);
-    apr_thread_rwlock_destroy(lock);
-#endif
-
-    return APR_SUCCESS;
-}
-#endif
-
 // Local Variables:
 // mode: c++
 // buffer-file-coding-system: euc-japan-dos
